<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//ca_CA

$LANG=array();


$LANG['backup'][0]="Còpia de seguretat en SQL"; 
$LANG['backup'][1]="Còpia de seguretat en XML"; 
$LANG['backup'][11]="Grandària"; 
$LANG['backup'][13]="Veure/Descarregar"; 
$LANG['backup'][16]="Està segur que vol reemplaçar la base de dades actual per l'arxiu de backup?:"; 
$LANG['backup'][17]="Està segur que vol eliminar aquest arxiu?:"; 
$LANG['backup'][18]="Està segur que vol guardar la base de dades?"; 
$LANG['backup'][19]="Ara"; 
$LANG['backup'][21]="El fitxer ja existeix"; 
$LANG['backup'][22]="No es troba el byte"; 
$LANG['backup'][23]="Error MySQL començant a"; 
$LANG['backup'][24]="Redirecció automàtica. Si no és així, fes clic"; 

$LANG['bookmark'][1]="marcador"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="No té marcadors guardats"; 
$LANG['bookmark'][4]="Nou marcador"; 
$LANG['bookmark'][5]="Marcadors Públics"; 
$LANG['bookmark'][6]="Vista principal"; 

$LANG['buttons'][0]="Buscar"; 
$LANG['buttons'][2]="Validar"; 
$LANG['buttons'][3]="Assignar"; 
$LANG['buttons'][4]="Instal·lar"; 
$LANG['buttons'][5]="Desinstal.lar"; 
$LANG['buttons'][6]="Esborrar"; 
$LANG['buttons'][7]="Actualitzar"; 
$LANG['buttons'][8]="Afegir"; 
$LANG['buttons'][9]="Connectar"; 
$LANG['buttons'][10]="Desconnectar"; 
$LANG['buttons'][11]="Següent"; 
$LANG['buttons'][12]="Anterior"; 
$LANG['buttons'][13]="Tornar"; 
$LANG['buttons'][14]="Modificar"; 
$LANG['buttons'][15]="Calendari"; 
$LANG['buttons'][16]="Esborrar"; 
$LANG['buttons'][17]="Invertir la selecció"; 
$LANG['buttons'][18]="Marcar tot"; 
$LANG['buttons'][19]="Desmarcar tot"; 
$LANG['buttons'][20]="Moure"; 
$LANG['buttons'][21]="Restaurar"; 
$LANG['buttons'][22]="Purgar"; 
$LANG['buttons'][23]="Veure"; 
$LANG['buttons'][24]="Ascendir"; 
$LANG['buttons'][25]="Descendir"; 
$LANG['buttons'][27]="Vista en format PDF"; 
$LANG['buttons'][28]="Vista en format SLK"; 
$LANG['buttons'][29]="Tot en format PDF"; 
$LANG['buttons'][30]="Tot en format SLK"; 
$LANG['buttons'][31]="Exportar"; 
$LANG['buttons'][32]="Fi"; 
$LANG['buttons'][33]="Principi"; 
$LANG['buttons'][34]="Cancel.lar"; 
$LANG['buttons'][37]="Importar"; 
$LANG['buttons'][38]="Desmarcar"; 
$LANG['buttons'][39]="Reemplaçar"; 
$LANG['buttons'][40]="Veure tots"; 
$LANG['buttons'][41]="Activar"; 
$LANG['buttons'][42]="Desactivar"; 
$LANG['buttons'][43]="Examinar"; 
$LANG['buttons'][44]="Vista en format CSV"; 
$LANG['buttons'][45]="Tot en format CSV"; 
$LANG['buttons'][46]="Abans"; 
$LANG['buttons'][47]="Després"; 
$LANG['buttons'][48]="Transferir"; 
$LANG['buttons'][49]="Conservar"; 
$LANG['buttons'][50]="Provar"; 
$LANG['buttons'][51]="Registrar"; 
$LANG['buttons'][52]="Carregar"; 
$LANG['buttons'][53]="Netejar"; 
$LANG['buttons'][55]="Primer"; 
$LANG['buttons'][56]="Últim"; 
$LANG['buttons'][57]="Executar"; 
$LANG['buttons'][58]="Actualitzar"; 
$LANG['buttons'][59]="Dissociar"; 

$LANG['calendar'][0]="AAAA-MM-DD"; 
$LANG['calendar'][1]="DD-MM-AAAA"; 
$LANG['calendar'][2]="MM-DD-AAAA"; 

$LANG['calendarD'][0]="D"; 
$LANG['calendarD'][1]="L"; 
$LANG['calendarD'][2]="M"; 
$LANG['calendarD'][3]="M"; 
$LANG['calendarD'][4]="J"; 
$LANG['calendarD'][5]="V"; 
$LANG['calendarD'][6]="S"; 

$LANG['calendarDay'][0]="Diumenge"; 
$LANG['calendarDay'][1]="Dilluns"; 
$LANG['calendarDay'][2]="Dimarts"; 
$LANG['calendarDay'][3]="Dimecres"; 
$LANG['calendarDay'][4]="Dijous"; 
$LANG['calendarDay'][5]="Divendres"; 
$LANG['calendarDay'][6]="Dissabte"; 

$LANG['calendarM'][0]="Gener"; 
$LANG['calendarM'][1]="Febrer"; 
$LANG['calendarM'][2]="Març"; 
$LANG['calendarM'][3]="Abril"; 
$LANG['calendarM'][4]="Maig"; 
$LANG['calendarM'][5]="Juny"; 
$LANG['calendarM'][6]="Juliol"; 
$LANG['calendarM'][7]="Agost"; 
$LANG['calendarM'][8]="Setembre"; 
$LANG['calendarM'][9]="Octubre"; 
$LANG['calendarM'][10]="Novembre"; 
$LANG['calendarM'][11]="Desembre"; 

$LANG['cartridges'][0]="Cartutx"; 
$LANG['cartridges'][7]="No s'han trobat cartutxos"; 
$LANG['cartridges'][9]="No hi ha cartutxos"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Doll"; 
$LANG['cartridges'][12]="Tipus de cartutx"; 
$LANG['cartridges'][13]="Nou(s)"; 
$LANG['cartridges'][14]="Usat(s)"; 
$LANG['cartridges'][15]="Utilitzats"; 
$LANG['cartridges'][16]="Cartutx(s)"; 
$LANG['cartridges'][20]="Nou"; 
$LANG['cartridges'][21]="Usat"; 
$LANG['cartridges'][22]="Utilitzat"; 
$LANG['cartridges'][24]="Agregat data"; 
$LANG['cartridges'][27]="Sobre"; 
$LANG['cartridges'][29]="Terme de vida"; 
$LANG['cartridges'][32]="Models d'impressores compatibles"; 
$LANG['cartridges'][33]="Cartutxos usats"; 
$LANG['cartridges'][34]="No hi ha cartutxos lliures"; 
$LANG['cartridges'][35]="Cartutxos vells"; 
$LANG['cartridges'][37]="Cinta"; 
$LANG['cartridges'][39]="Comptador d'impressora"; 
$LANG['cartridges'][40]="Terme mitjà en estoc"; 
$LANG['cartridges'][41]="Utilització terme mitjà"; 
$LANG['cartridges'][42]="Pàgines impreses, terme mitjà"; 

$LANG['central'][2]="Últims"; 
$LANG['central'][4]="Sense events"; 
$LANG['central'][5]="Inici"; 
$LANG['central'][6]="Desconnexió"; 
$LANG['central'][7]="Ajuda"; 
$LANG['central'][8]="Agregats"; 
$LANG['central'][9]="Les seves incidències en curs"; 
$LANG['central'][10]="Incidències noves"; 
$LANG['central'][12]="Vista personal"; 
$LANG['central'][13]="Vista global"; 
$LANG['central'][14]="Vista de grup"; 
$LANG['central'][18]="Els teus incidents a tancar"; 
$LANG['central'][19]="Les seves peticions a validar"; 

$LANG['choice'][0]="No"; 
$LANG['choice'][1]="Sí"; 

$LANG['common'][0]="Sense nom"; 
$LANG['common'][1]="Material"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Veure els elements eliminats"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Fabricant"; 
$LANG['common'][6]="Nom de la plantilla"; 
$LANG['common'][7]="Escolleix una plantilla"; 
$LANG['common'][8]="Gestió de plantilles..."; 
$LANG['common'][9]="Afegir una plantilla..."; 
$LANG['common'][10]="Responsable tècnic"; 
$LANG['common'][11]="Vista limitada"; 
$LANG['common'][12]="Configuració"; 
$LANG['common'][13]="Plantilla"; 
$LANG['common'][14]="Plantilles"; 
$LANG['common'][15]="Lloc"; 
$LANG['common'][16]="Nom"; 
$LANG['common'][17]="Tipus"; 
$LANG['common'][18]="Contacte"; 
$LANG['common'][19]="Número de serie"; 
$LANG['common'][20]="Número d'inventari"; 
$LANG['common'][21]="Numero de contacte"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="Operació realitzada amb èxit"; 
$LANG['common'][24]="No s'han seleccionat elements o l'operació està mal definida"; 
$LANG['common'][25]="Comentaris"; 
$LANG['common'][26]="Última modificació"; 
$LANG['common'][27]="Data"; 
$LANG['common'][28]="Esborrat"; 
$LANG['common'][29]="Plugins"; 
$LANG['common'][30]="Nou ítem"; 
$LANG['common'][31]="Plantilla buida"; 
$LANG['common'][32]="Característiques"; 
$LANG['common'][33]="Total"; 
$LANG['common'][34]="Usuari"; 
$LANG['common'][35]="Grup"; 
$LANG['common'][36]="Categoria"; 
$LANG['common'][37]="Autor"; 
$LANG['common'][38]="Des-globalitzar"; 
$LANG['common'][39]="Replica l'element tantes vegades com connexions"; 
$LANG['common'][40]="Segur que desitja des-globalitzar aquest element?"; 
$LANG['common'][41]="Alertes per correu electrònic"; 
$LANG['common'][42]="Mòbil"; 
$LANG['common'][43]="Nom"; 
$LANG['common'][44]="Valor predeterminat"; 
$LANG['common'][45]="MB màxims"; 
$LANG['common'][46]="vCard"; 
$LANG['common'][47]="Progrés"; 
$LANG['common'][48]="Cognom"; 
$LANG['common'][49]="Cap"; 
$LANG['common'][50]="Confirma l'eliminació?"; 
$LANG['common'][51]="Nom complet"; 
$LANG['common'][52]="Servidor"; 
$LANG['common'][53]="Llista"; 
$LANG['common'][54]="L'element no es troba"; 
$LANG['common'][55]="Està segur que desitja esborrar aquest element?"; 
$LANG['common'][56]="Interfície estàndard"; 
$LANG['common'][57]="Títol"; 
$LANG['common'][58]="Valor màxim"; 
$LANG['common'][59]="Global"; 
$LANG['common'][60]="Actiu"; 
$LANG['common'][61]="Error desconegut"; 
$LANG['common'][62]="Altre."; 
$LANG['common'][63]="Errors"; 
$LANG['common'][64]="Supervisor"; 
$LANG['common'][65]="Interface"; 
$LANG['common'][66]="Tots"; 
$LANG['common'][67]="Altres"; 
$LANG['common'][68]="Apaïsat"; 
$LANG['common'][69]="Retrat"; 
$LANG['common'][70]="Element afegit correctament"; 
$LANG['common'][71]="Element modificat correctament"; 
$LANG['common'][72]="Element eliminat correctament"; 
$LANG['common'][73]="Element purgat correctament"; 
$LANG['common'][74]="Element restaurat correctament"; 
$LANG['common'][75]="No té permisos per a fer recursiu a l'element en aquesta entitat"; 
$LANG['common'][76]="Públic"; 
$LANG['common'][77]="Privat"; 
$LANG['common'][78]="Fer Públic"; 
$LANG['common'][79]="Fer Privat"; 
$LANG['common'][80]="Durant la càrrega"; 
$LANG['common'][81]="No mostrar items esborrats"; 
$LANG['common'][82]="Mb"; 
$LANG['common'][83]="Vostè no té permisos per a realitzar aquesta acció."; 
$LANG['common'][84]="L'existencia d'elements enllaçats impideixen la modificació d'aquest atribut"; 
$LANG['common'][85]="Modificar la visibilitat a les sub-entitats"; 
$LANG['common'][86]="Vostè no té permisos suficients per a modificar la visibilitat a les sub-entitats"; 
$LANG['common'][87]="Nova targeta"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Sense instal·lar"; 
$LANG['common'][90]="Objecte"; 
$LANG['common'][91]="Aquest element es dependent d'una altre.La modificació no està permesa"; 
$LANG['common'][92]="Contacte"; 
$LANG['common'][93]="Nou títol fill"; 

$LANG['computers'][0]="Volum"; 
$LANG['computers'][1]="Percentatge lliure"; 
$LANG['computers'][2]="Grandària lliure"; 
$LANG['computers'][3]="Grandària global"; 
$LANG['computers'][4]="Sistema d'arxius"; 
$LANG['computers'][5]="Partició"; 
$LANG['computers'][6]="Punt de muntatge"; 
$LANG['computers'][7]="Afegint un volumen"; 
$LANG['computers'][8]="Volums"; 
$LANG['computers'][9]="S.O."; 
$LANG['computers'][10]="Número de serie del S.O."; 
$LANG['computers'][11]="Id. de producte del S.O."; 
$LANG['computers'][14]="Afegit"; 
$LANG['computers'][23]="Tipus de RAM"; 
$LANG['computers'][24]="Quantitat de RAM(MB)"; 
$LANG['computers'][25]="Grandària HD"; 
$LANG['computers'][36]="Tipus d'HD"; 
$LANG['computers'][37]="No hi ha monitor connectat"; 
$LANG['computers'][38]="No hi ha impressores connectades"; 
$LANG['computers'][39]="Impressores"; 
$LANG['computers'][40]="Monitors"; 
$LANG['computers'][46]="Perifèrics"; 
$LANG['computers'][47]="No hi ha perifèrics connectats"; 
$LANG['computers'][48]="Modificació del lloc. Els elements connectats han sigut desplaçats al mateix lloc que l'ordinador."; 
$LANG['computers'][49]="Modificació de l'usuari de contacte. Els elements connectats han pres com a contacte el de l'ordinador."; 
$LANG['computers'][50]="Modificació de l'usuari o del grup. Els elements relacionats han sigut actualitzats amb els mateixos valors que l'equip."; 
$LANG['computers'][51]="Origen d'actualització"; 
$LANG['computers'][52]="Versió S.O."; 
$LANG['computers'][53]="Service Pack"; 
$LANG['computers'][54]="No hi ha telèfon connectat"; 
$LANG['computers'][55]="Telèfon(s)"; 
$LANG['computers'][56]="Modificació de l'estat. Els elements relacionats s'han actualitzat amb l'estat de l'ordinador."; 

$LANG['connect'][0]="Connexions directes"; 
$LANG['connect'][1]="No conectat"; 
$LANG['connect'][15]="Actualització automàtica dels elements següents"; 
$LANG['connect'][16]="Compte! Els següents elements dels dos ordinadors no coincideixen"; 

$LANG['consumables'][0]="Consumibles"; 
$LANG['consumables'][1]="En stock"; 
$LANG['consumables'][2]="Referència"; 
$LANG['consumables'][7]="No s'han trobat consumibles"; 
$LANG['consumables'][9]="Cap consumible"; 
$LANG['consumables'][12]="Tipus de consumible"; 
$LANG['consumables'][13]="Nou(s)"; 
$LANG['consumables'][15]="Utilitzat(s)"; 
$LANG['consumables'][16]="Consumible(s)"; 
$LANG['consumables'][20]="Nou"; 
$LANG['consumables'][22]="Utilitzats"; 
$LANG['consumables'][23]="Estat"; 
$LANG['consumables'][26]="Utilitzat data"; 
$LANG['consumables'][32]="Donar"; 
$LANG['consumables'][35]="Consumibles usats"; 
$LANG['consumables'][36]="Lloc d'emmagatzematge"; 
$LANG['consumables'][37]="Reintegrar a l'estoc"; 
$LANG['consumables'][38]="Llindar d'alarma"; 

$LANG['contract'][0]="Contracte vençut des de"; 
$LANG['contract'][1]="Contracte en preavís des de"; 

$LANG['crontask'][0]="Tasques programades"; 
$LANG['crontask'][1]="Sincronitza equips des de OCSNG"; 
$LANG['crontask'][2]="Alertes sobre cartutxos"; 
$LANG['crontask'][3]="Enviament avís material de consum"; 
$LANG['crontask'][4]="Enviament d'alertes per llicencies expirades"; 
$LANG['crontask'][5]="Enviament avís de contractes"; 
$LANG['crontask'][6]="Enviament d'alerta sobre informació financera"; 
$LANG['crontask'][7]="Esborrat logs antics"; 
$LANG['crontask'][8]="Optimització de la base de dades"; 
$LANG['crontask'][9]="Recuperar correu"; 
$LANG['crontask'][10]="Verificació de la replica de MYSQL"; 
$LANG['crontask'][11]="Comprovar actualitzacions"; 
$LANG['crontask'][12]="Neteja de les sessions expirades"; 
$LANG['crontask'][13]="Neteja dels gràfics generats"; 
$LANG['crontask'][14]="Tancament administratiu dels incidents"; 
$LANG['crontask'][15]="Incidents sense resoldre"; 
$LANG['crontask'][31]="Desactivada"; 
$LANG['crontask'][32]="Programat"; 
$LANG['crontask'][33]="En procés d'execució."; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Mode d'execució"; 
$LANG['crontask'][37]="Freqüència d'execució"; 
$LANG['crontask'][38]="Període d'execució"; 
$LANG['crontask'][39]="Número de missatges per a recuperar"; 
$LANG['crontask'][40]="Última execució"; 
$LANG['crontask'][41]="Propera execució"; 
$LANG['crontask'][42]="Com més aviat millor"; 
$LANG['crontask'][43]="Sense tasca a realitzar"; 
$LANG['crontask'][44]="Tasca finalitzada, procés parcial"; 
$LANG['crontask'][45]="Tasca finalitzada, procés complet"; 
$LANG['crontask'][46]="Tasca finalitzada, res a fer"; 
$LANG['crontask'][47]="Llistat de les últimes execucions"; 
$LANG['crontask'][48]="Inici"; 
$LANG['crontask'][50]="Número de execucions"; 
$LANG['crontask'][51]="Durada mínima"; 
$LANG['crontask'][52]="Durada màxima"; 
$LANG['crontask'][53]="Durada mitja"; 
$LANG['crontask'][55]="Número mínim"; 
$LANG['crontask'][56]="Número màxim"; 
$LANG['crontask'][57]="Número mitjà"; 
$LANG['crontask'][58]="Número total"; 
$LANG['crontask'][59]="Velocitat mitja"; 
$LANG['crontask'][60]="Sistema bloquejat"; 
$LANG['crontask'][61]="Plugin desactivat"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Afegir un nou component"; 
$LANG['devices'][1]="Disc dur"; 
$LANG['devices'][2]="Tarja de vídeo"; 
$LANG['devices'][3]="Tarja de xarxa"; 
$LANG['devices'][4]="Processador"; 
$LANG['devices'][5]="Placa base"; 
$LANG['devices'][6]="Memòria RAM"; 
$LANG['devices'][7]="Tarja de so"; 
$LANG['devices'][19]="Lectores"; 
$LANG['devices'][20]="Controladores"; 
$LANG['devices'][21]="Altres components"; 
$LANG['devices'][22]="Caixes"; 
$LANG['devices'][23]="Alimentació"; 
$LANG['devices'][24]="predeterminat"; 
$LANG['devices'][25]="Afegir un component"; 
$LANG['devices'][26]="Esborrat d'un component"; 

$LANG['device_case'][0]="format"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Gravació"; 
$LANG['device_drive'][1]="Velocitat"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Cau"; 
$LANG['device_hdd'][4]="Capacitat"; 

$LANG['device_iface'][0]="Velocitat"; 
$LANG['device_iface'][2]="Adreça MAC"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Potencia"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Freqüència"; 
$LANG['device_ram'][2]="Grandària"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Arxiu"; 
$LANG['document'][3]="Assumpte"; 
$LANG['document'][4]="Tipus MIME"; 
$LANG['document'][7]="Tipus de document"; 
$LANG['document'][9]="Extensió"; 
$LANG['document'][10]="Icona"; 
$LANG['document'][11]="Descàrrega autoritzada"; 
$LANG['document'][15]="Descàrrega"; 
$LANG['document'][16]="Afegir un Document"; 
$LANG['document'][18]="Document"; 
$LANG['document'][19]="Elements associats"; 
$LANG['document'][21]="Documents Associats"; 
$LANG['document'][22]="Arxiu actual"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Esborrat correcte del fitxer"; 
$LANG['document'][25]="Va fallar l'esborrat del fitxer"; 
$LANG['document'][26]="El fitxer és vàlid, i ha sigut descarregat correctament."; 
$LANG['document'][27]="Potencial atac per upload, o arxiu massa gran. Impossible moure l'arxiu temporal."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Va fallar la creació del directori"; 
$LANG['document'][30]="Comprovi que té vostè permisos"; 
$LANG['document'][31]="Directori d'emmagatzematge de documents inexistent:"; 
$LANG['document'][32]="Tipus d'arxiu no autoritzat"; 
$LANG['document'][33]="Enllaç Web"; 
$LANG['document'][34]="Creació del directori"; 
$LANG['document'][35]="Directori de pujada inexistent"; 
$LANG['document'][36]="Seleccionar un arxiu instal·lat per FTP"; 
$LANG['document'][37]="No hi ha arxius disponibles"; 
$LANG['document'][38]="Arxiu no trobat"; 
$LANG['document'][39]="Document mogut correctament"; 
$LANG['document'][40]="Problema al moure l'arxiu"; 
$LANG['document'][41]="Document copiat correctament"; 
$LANG['document'][42]="Afegit per"; 
$LANG['document'][43]="Arxiu desconegut"; 
$LANG['document'][44]="Nom d'arxiu incorrecte"; 
$LANG['document'][45]="No tens permisos per accedir-hi a aquest arxiu"; 
$LANG['document'][46]="Fallo a l'enviar l'arxiu (massa gran)"; 
$LANG['document'][48]="Ja existeix un document amb aquest arxiu"; 
$LANG['document'][49]="Arxiu alterat (checksum erroni)"; 
$LANG['document'][50]="Elements adjunts"; 

$LANG['entity'][0]="Entitat"; 
$LANG['entity'][2]="Entitat arrel"; 
$LANG['entity'][3]="Associar a una entitat"; 
$LANG['entity'][5]="Assignació automàtica d'ordinadors"; 
$LANG['entity'][6]="Assignació automàtica d'ordinadors"; 
$LANG['entity'][7]="estructura d'arbre"; 
$LANG['entity'][8]="Per entitat"; 
$LANG['entity'][9]="Sots-entitats"; 
$LANG['entity'][10]="Seleccionar l'entitat desitjada"; 
$LANG['entity'][11]="per a veure l'entitat i les seves subentitats"; 
$LANG['entity'][12]="DN de l'entitat"; 
$LANG['entity'][13]="TAG de l'entitat"; 
$LANG['entity'][14]="Informació avançada"; 
$LANG['entity'][15]="Directori associat a l'entitat"; 
$LANG['entity'][16]="Filtro de cerca (si fos necessari)"; 
$LANG['entity'][17]="Configuració pel tancament administratiu"; 
$LANG['entity'][18]="Tancament administratiu dels incidents després de resolts"; 

$LANG['event'][0]="Item (ID)"; 
$LANG['event'][2]="Incidència"; 
$LANG['event'][3]="Nivell"; 
$LANG['event'][4]="Missatge"; 
$LANG['event'][18]="Camp"; 
$LANG['event'][19]="Modificació"; 
$LANG['event'][20]="No hi ha històric"; 

$LANG['financial'][1]="Contracte"; 
$LANG['financial'][2]="Té vida"; 
$LANG['financial'][3]="Dades financeres"; 
$LANG['financial'][4]="Número"; 
$LANG['financial'][5]="Cost"; 
$LANG['financial'][6]="Tipus de contracte"; 
$LANG['financial'][8]="Duració"; 
$LANG['financial'][9]="any(s)"; 
$LANG['financial'][10]="Preavís"; 
$LANG['financial'][11]="Periodicitat de facturació"; 
$LANG['financial'][13]="Número comptable"; 
$LANG['financial'][14]="Data de compra"; 
$LANG['financial'][15]="Duració de la garantia"; 
$LANG['financial'][16]="Dades de garantia"; 
$LANG['financial'][18]="Número de demanda"; 
$LANG['financial'][19]="Remeto de lliurament"; 
$LANG['financial'][20]="Número d'inhibició"; 
$LANG['financial'][21]="Preu de compra"; 
$LANG['financial'][22]="Tipus d'amortització"; 
$LANG['financial'][23]="Duració d'amortització"; 
$LANG['financial'][24]="Afegir Contacte..."; 
$LANG['financial'][25]="Afegir Empresa..."; 
$LANG['financial'][26]="Proveïdor"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Afegir un Contacte"; 
$LANG['financial'][36]="Afegir un Contracte"; 
$LANG['financial'][42]="Comercial"; 
$LANG['financial'][43]="Tècnic"; 
$LANG['financial'][44]="Adreça"; 
$LANG['financial'][45]="Lloc Web"; 
$LANG['financial'][46]="Contactes associats"; 
$LANG['financial'][47]="Lineal"; 
$LANG['financial'][48]="Reduït"; 
$LANG['financial'][50]="Prestam"; 
$LANG['financial'][51]="Localització"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Assegurances"; 
$LANG['financial'][54]="Manteniment Hardware"; 
$LANG['financial'][55]="Manteniment de Programari"; 
$LANG['financial'][56]="Prestació"; 
$LANG['financial'][57]="mes"; 
$LANG['financial'][59]="Hores de servei"; 
$LANG['financial'][60]="de setmana"; 
$LANG['financial'][61]="dissabte"; 
$LANG['financial'][62]="Diumenges i festius"; 
$LANG['financial'][65]="Proveïdors associats"; 
$LANG['financial'][66]="Contractes associats"; 
$LANG['financial'][68]="Activar les dades financeres"; 
$LANG['financial'][69]="Periodicitat del contracte"; 
$LANG['financial'][76]="Data de posada en servei"; 
$LANG['financial'][77]="Coeficient d'amortització"; 
$LANG['financial'][78]="Preu extensió garantia"; 
$LANG['financial'][79]="Tipus de Tercer"; 
$LANG['financial'][80]="Expiració de garantia"; 
$LANG['financial'][81]="Valor Neto Contable (VNC)"; 
$LANG['financial'][82]="Número de factura"; 
$LANG['financial'][83]="Quantitat màxima d'elements (0=sense límits)"; 
$LANG['financial'][84]="Per aquest tipus d'element, les dades financeres no son més que un model pels elements que afegiràs a continuació."; 
$LANG['financial'][85]="No s'ha trobat l'element sol·licitat"; 
$LANG['financial'][86]="Caducitat del contracte"; 
$LANG['financial'][87]="Pressupost"; 
$LANG['financial'][88]="Expira el:"; 
$LANG['financial'][89]="CTP (preu de compra + cost d'incidències)"; 
$LANG['financial'][90]="CTP mensual"; 
$LANG['financial'][91]="CTP"; 
$LANG['financial'][92]="VNC"; 
$LANG['financial'][93]="Contracte(s) expirat(s) fa menys de 30 dies"; 
$LANG['financial'][94]="Contracte(s) que expira(n) en menys de 7 dies"; 
$LANG['financial'][95]="Contracte(s) que expira(n) en menys de 30 dies"; 
$LANG['financial'][96]="Contracte(s) el preavís del qual comença en menys de 7 dies"; 
$LANG['financial'][97]="Contracte(s) el preavís del quals comença en menys de 30 dies"; 
$LANG['financial'][98]="Expiració"; 
$LANG['financial'][99]="Expiració + preavís"; 
$LANG['financial'][100]="Codi postal"; 
$LANG['financial'][101]="Ciutat"; 
$LANG['financial'][102]="Estat"; 
$LANG['financial'][103]="País"; 
$LANG['financial'][104]="Material conectat"; 
$LANG['financial'][105]="Tàcit"; 
$LANG['financial'][106]="Expressa"; 
$LANG['financial'][107]="Renovació"; 
$LANG['financial'][108]="Total gastat al pressupost"; 
$LANG['financial'][109]="Total restant del pressupost"; 
$LANG['financial'][110]="Pressupostos"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="hores"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matriu de càlcul de la prioritat"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Molt urgent"; 
$LANG['help'][4]="Urgent"; 
$LANG['help'][5]="Mitjana"; 
$LANG['help'][6]="Baixa"; 
$LANG['help'][7]="Molt baixa"; 
$LANG['help'][8]="Informa'm del seguiment"; 
$LANG['help'][11]="La meva adreça d'email"; 
$LANG['help'][14]="Enviar missatge"; 
$LANG['help'][16]="Si desitja estar informat del seguiment deu ingressar l'adreça electrònica"; 
$LANG['help'][18]="La seva sol·licitud ha estat enviada, tractament en curs."; 
$LANG['help'][19]="Gràcies per utilitzar el nostre sistema d'ajuda automàtica."; 
$LANG['help'][22]="Buscar el seu número d'ordinador"; 
$LANG['help'][23]="Teclegi les primeres lletres (nom, material, nº de serie o nº d'inventari)"; 
$LANG['help'][24]="Tipus de material"; 
$LANG['help'][25]="Ordinador"; 
$LANG['help'][26]="Material de xarxa"; 
$LANG['help'][27]="Impressora"; 
$LANG['help'][28]="Monitor"; 
$LANG['help'][29]="Perifèric"; 
$LANG['help'][30]="General"; 
$LANG['help'][31]="Programari"; 
$LANG['help'][35]="Telèfons"; 
$LANG['help'][40]="Incidents sense títols, si us plau, introdueix el títol."; 
$LANG['help'][41]="La incidència no conté categoria. Si us plau, selecciona una."; 
$LANG['help'][42]="Molt alt"; 
$LANG['help'][43]="Alta"; 
$LANG['help'][44]="Mitjana"; 
$LANG['help'][45]="Baixa"; 
$LANG['help'][46]="Molt baixa"; 
$LANG['help'][47]="Molt alt"; 
$LANG['help'][48]="Alt"; 
$LANG['help'][49]="Mitjà"; 
$LANG['help'][50]="Sota"; 
$LANG['help'][51]="Molt baix"; 

$LANG['install'][0]="Instal·lació o actualització de GLPI"; 
$LANG['install'][1]="Trii 'Instal.lació' per a una nova instal.lació completa de GLPI"; 
$LANG['install'][2]="Trii 'Actualització' per a actualitzar GLPI a partir d'una versió anterior"; 
$LANG['install'][3]="Instal·lació"; 
$LANG['install'][4]="Actualització"; 
$LANG['install'][5]="Verificació de la comptabilitat del seu entorn amb l'execució de GLPI"; 
$LANG['install'][6]="Prova efectuada"; 
$LANG['install'][7]="Resultats"; 
$LANG['install'][8]="Prova de l'interpret PHP"; 
$LANG['install'][9]="Ha d'instal·lar al menys PHP5. Pot descarregar-lo d'aquí:"; 
$LANG['install'][10]="GLPI no es compatible amb la directiva zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="La versió de PHP es 5.x o superior - Perfecte!"; 
$LANG['install'][12]="Prova de Sessions"; 
$LANG['install'][13]="El seu intèrpret PHP no ha sigut compilat amb suport de sessions!"; 
$LANG['install'][14]="El suport de sessions està operatiu - Perfecte!"; 
$LANG['install'][15]="Comprovi que estigui activat el suport de sessions en el seu php.ini"; 
$LANG['install'][16]="Proves d'escriptura d'arxius dump"; 
$LANG['install'][17]="No s'ha pogut crear l'arxiu."; 
$LANG['install'][18]="Les traduccions no oficials estan també disponibles"; 
$LANG['install'][19]="El fitxer ha estat creat però no s'ha pogut esborrar."; 
$LANG['install'][20]="El fitxer i un directori han estat creats i eliminats - Perfecte!"; 
$LANG['install'][21]="Prova d'escriptura d'arxius de documents"; 
$LANG['install'][22]="Un arxiu ha estat creat - Perfecte!"; 
$LANG['install'][23]="Prova d'escriptura de l'arxiu de configuració"; 
$LANG['install'][24]="Inicialització de la base de dades"; 
$LANG['install'][25]="Continuar?"; 
$LANG['install'][26]="Continuar"; 
$LANG['install'][27]="Reintentar"; 
$LANG['install'][28]="Configuració de la connexió a la base de dades"; 
$LANG['install'][29]="Paràmetres de connexió a la base de dades"; 
$LANG['install'][30]="Servidor Mysql"; 
$LANG['install'][31]="Usuari Mysql"; 
$LANG['install'][32]="Contrasenya Mysql"; 
$LANG['install'][34]="Prova de la connexió a la base de dades"; 
$LANG['install'][35]="Impossible connectar-se a la base de dades"; 
$LANG['install'][36]="El servidor ha respost"; 
$LANG['install'][37]="El camp servidor i/o el camp usuari estan buits"; 
$LANG['install'][38]="Selecciona una base de dades:"; 
$LANG['install'][39]="Crear una nova base de dades o utilitzar la que ja existeix:"; 
$LANG['install'][40]="Selecciona la base de dades a actualitzar:"; 
$LANG['install'][41]="Impossible utilitzar la base:"; 
$LANG['install'][43]="OK - La base ha sigut inicialitzada"; 
$LANG['install'][47]="Impossible escriure l'arxiu de configuració de la seva BD"; 
$LANG['install'][48]="Error en la creació de la base!"; 
$LANG['install'][49]="No ha seleccionat base de dades!"; 
$LANG['install'][50]="Prova d'escriptura d'arxius de sessions"; 
$LANG['install'][52]="Prova d'escriptura d'arxius de cron"; 
$LANG['install'][53]="Prova d'escriptura dels arxius de log"; 
$LANG['install'][55]="La instal.lació ha acabat"; 
$LANG['install'][57]="Els logins i claus predeterminades son:"; 
$LANG['install'][58]="glpi/glpi per al compte administrador"; 
$LANG['install'][59]="tech/tech pel compte del tècnic"; 
$LANG['install'][60]="normal pel compte normal"; 
$LANG['install'][61]="post-only/post-only pel compte postonly"; 
$LANG['install'][62]="Pot esborrar o modificar aquests comptes i les primeres entrades a la base de dades"; 
$LANG['install'][64]="Utilitzar GLPI"; 
$LANG['install'][65]="Prova de l'extensió magic_quotes_sybase"; 
$LANG['install'][66]="GLPI no pot funcionar amb l'opció magic_quotes_sybase. Desactiva aquesta opció i reintenta"; 
$LANG['install'][67]="El seu servidor no utilitza l'opció magic_quotes_sybase - Perfecte!"; 
$LANG['install'][68]="Prova sessió d'autoinici"; 
$LANG['install'][69]="session.auto_start està activat. Revisar l'arxiu .htaccess a l'arrel de GLPI per a més informació"; 
$LANG['install'][70]="Impossible crear l'arxiu de connexió a la base de dades, comprova els permisos dels arxius"; 
$LANG['install'][71]="Prova de l'extensió mysql."; 
$LANG['install'][72]="Ha de compilar el seu PHP amb l'extensió Mysql."; 
$LANG['install'][73]="OK - la funció mysql_query() existeix - Perfecte!"; 
$LANG['install'][74]="Prova d'utilització de Session_use_trans_sid"; 
$LANG['install'][75]="Ha de desactivar l'opció Session_use_trans_id en el seu PHP.ini"; 
$LANG['install'][76]="OK - Les sessions funcionen (no n'hi han problemes de trans_id) - Perfecte!"; 
$LANG['install'][77]="Etapa"; 
$LANG['install'][81]="Inici de la instal·lació"; 
$LANG['install'][82]="Bases de dades creades"; 
$LANG['install'][85]="S'han trobat les funcions - Perfecte!"; 
$LANG['install'][86]="Comprovar la memòria assignada"; 
$LANG['install'][87]="Memòria assignada:"; 
$LANG['install'][88]="Generalment es necessita un mínim de 64MB per a GLPI."; 
$LANG['install'][89]="Perfecte!"; 
$LANG['install'][90]="Intenta augmentar el paràmetre memory limit a l'arxiu php.ini"; 
$LANG['install'][91]="Memòria assignada > 64 MB"; 
$LANG['install'][92]="Llicencia"; 
$LANG['install'][93]="He llegit i accept els termes de la llicencia comentats a dalt."; 
$LANG['install'][94]="He llegit i NO accepto els termes de la llicencia comentats a dalt."; 
$LANG['install'][95]="Memòria no limitada"; 
$LANG['install'][96]="Memòria il·limitada"; 
$LANG['install'][97]="Comprovi que PHP té permís d'escriptura al directori:"; 
$LANG['install'][99]="Prova d'escriptura dels arxius de caché"; 
$LANG['install'][100]="No s'ha pogut crear el directori."; 
$LANG['install'][101]="S'ha creat el directori però no s'ha pogut eliminar."; 
$LANG['install'][102]="Proves de les funcions json"; 
$LANG['install'][103]="GLPI no pot funcionar correctament sense les funcions json_encode y json_decode"; 
$LANG['install'][104]="Prova de l'extensió mbstring"; 
$LANG['install'][105]="L'extensió mbstring de l'interpret PHP no està instal·lada"; 
$LANG['install'][106]="Prova d'escriptura dels arxius gràfics"; 

$LANG['job'][2]="per"; 
$LANG['job'][4]="Sol·licitant"; 
$LANG['job'][5]="Assignada a"; 
$LANG['job'][6]="Tècnic"; 
$LANG['job'][7]="Tasca"; 
$LANG['job'][8]="últim(s) incident(s)"; 
$LANG['job'][9]="Seguiment"; 
$LANG['job'][11]="Descrigui el problema/acció"; 
$LANG['job'][12]="No hi ha seguiment per aquesta incidència"; 
$LANG['job'][13]="Obrir un incident"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Seguiment per email"; 
$LANG['job'][20]="Duració total"; 
$LANG['job'][21]="Hores"; 
$LANG['job'][22]="Minuts"; 
$LANG['job'][29]="Afegir un nou seguiment"; 
$LANG['job'][30]="Afegir una nova tasca"; 
$LANG['job'][31]="Duració"; 
$LANG['job'][32]="Cap"; 
$LANG['job'][33]="Descripció buida"; 
$LANG['job'][34]="Planificar aquest seguiment"; 
$LANG['job'][35]="Planificació"; 
$LANG['job'][37]="Seguiment"; 
$LANG['job'][38]="Incidència"; 
$LANG['job'][39]="Modificar un seguiment"; 
$LANG['job'][40]="Cost horari"; 
$LANG['job'][41]="Cost fix"; 
$LANG['job'][42]="Cost del material"; 
$LANG['job'][43]="Cost total"; 
$LANG['job'][44]="Origen de sol·licitud"; 
$LANG['job'][45]="Origen del seguiment"; 
$LANG['job'][46]="Incident creat a l'entitat."; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Tipus de solució"; 
$LANG['job'][49]="Nova tasca"; 
$LANG['job'][50]="Sense tasques per a aquest incident"; 
$LANG['job'][51]="Aprovació de la solució"; 
$LANG['job'][52]="Actualitzar una tasca"; 
$LANG['job'][53]="Supressió d'una tasca"; 
$LANG['job'][54]="Sense una resposta l'incident s'eliminarà després de"; 

$LANG['joblist'][0]="Estat"; 
$LANG['joblist'][1]="Solament els meus"; 
$LANG['joblist'][2]="Prioritat"; 
$LANG['joblist'][3]="Els meus i els dels meus grups"; 
$LANG['joblist'][4]="Assignada a"; 
$LANG['joblist'][6]="Descripció"; 
$LANG['joblist'][7]="Nova incidència per aquest ítem..."; 
$LANG['joblist'][8]="No s'han trobat incidències."; 
$LANG['joblist'][9]="Nova"; 
$LANG['joblist'][10]="Tancada (resolta)"; 
$LANG['joblist'][11]="Oberta el"; 
$LANG['joblist'][12]="Tancada el"; 
$LANG['joblist'][13]="Incidents a processar"; 
$LANG['joblist'][14]="Solucionat el"; 
$LANG['joblist'][16]="No hi ha incidents pendents."; 
$LANG['joblist'][17]="Tancada (no resolta)"; 
$LANG['joblist'][18]="En curs (assignada)"; 
$LANG['joblist'][19]="En curs (planificada)"; 
$LANG['joblist'][21]="En curs"; 
$LANG['joblist'][26]="En espera"; 
$LANG['joblist'][27]="Correu Electrònic pel seguiment"; 
$LANG['joblist'][28]="Incident sobre els elements de xarxa"; 
$LANG['joblist'][29]="Urgència"; 
$LANG['joblist'][30]="Impacte"; 
$LANG['joblist'][32]="Resolt"; 
$LANG['joblist'][33]="Tancat"; 
$LANG['joblist'][34]="Sense resoldre"; 
$LANG['joblist'][35]="Sense tancar"; 
$LANG['joblist'][36]="Valor d'estat a la base de dades"; 

$LANG['jobresolution'][1]="Solució"; 
$LANG['jobresolution'][3]="Solució aprovada"; 
$LANG['jobresolution'][4]="Solució rebutjada"; 
$LANG['jobresolution'][5]="En cas de rebutjar la solució, deus indicar un motiu"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Col·locar aquest article en la FAQ pública"; 
$LANG['knowbase'][6]="Seleccionar una categoria per aquest article:"; 
$LANG['knowbase'][7]="Retira aquest article de les Preguntes Freqüents públiques"; 
$LANG['knowbase'][8]="Modificar aquest article"; 
$LANG['knowbase'][9]="Esborrar aquest article"; 
$LANG['knowbase'][10]="Aquest article forma part de la FAQ pública"; 
$LANG['knowbase'][11]="Aquest article no forma part de la FAQ pública"; 
$LANG['knowbase'][12]="Arrel"; 
$LANG['knowbase'][13]="Nom de la categoria"; 
$LANG['knowbase'][14]="Tema"; 
$LANG['knowbase'][15]="Contingut"; 
$LANG['knowbase'][24]="Accedir a les Preguntes Freqüents"; 
$LANG['knowbase'][26]="Vistes"; 
$LANG['knowbase'][27]="El"; 
$LANG['knowbase'][29]="Articles recents"; 
$LANG['knowbase'][30]="Articles més consultats"; 

$LANG['ldap'][0]="Importació massiva d'usuaris des d'un servidor"; 
$LANG['ldap'][1]="Sincronització dels usuaris ja importats"; 
$LANG['ldap'][2]="Importació d'usuaris nous"; 
$LANG['ldap'][3]="No hi ha usuaris que importar"; 
$LANG['ldap'][4]="Elecció del servidor LDAP"; 
$LANG['ldap'][5]="Trii el servidor LDAP del que s'importaran els usuaris"; 
$LANG['ldap'][6]="Impossible connectar amb el servidor LDAP"; 
$LANG['ldap'][7]="No hi ha cap servidor LDAP definit a GLPI"; 
$LANG['ldap'][8]="Compte: La resposta excedeix el límit de l'LDAP. Els resultats son parcials"; 
$LANG['ldap'][9]="Prova de connexió amb el servidor LDAP"; 
$LANG['ldap'][12]="Sincronització"; 
$LANG['ldap'][13]="a LDAP"; 
$LANG['ldap'][14]="a GLPI"; 
$LANG['ldap'][15]="Sincronitzar"; 
$LANG['ldap'][16]="Configuració previa"; 
$LANG['ldap'][17]="Directori Actiu"; 
$LANG['ldap'][18]="Llista de repliques d'LDAP"; 
$LANG['ldap'][19]="Replicat"; 
$LANG['ldap'][20]="Afegir una rèplica LDAP"; 
$LANG['ldap'][21]="Servidor primari"; 
$LANG['ldap'][22]="Rèplica/Rèpliques"; 
$LANG['ldap'][23]="Importació massiva de grups des d'un servidor LDAP"; 
$LANG['ldap'][24]="Importació de nous grups"; 
$LANG['ldap'][25]="Cap grup per a ser importat"; 
$LANG['ldap'][30]="Tractament dels alies LDAP"; 
$LANG['ldap'][31]="Mai (defecte)"; 
$LANG['ldap'][32]="Sempre"; 
$LANG['ldap'][33]="Desreferenciat a la cerca"; 
$LANG['ldap'][34]="Desreferenciat a la localització"; 
$LANG['ldap'][35]="Importar un usuari"; 
$LANG['ldap'][36]="Cap directori associat amb l'entitat"; 
$LANG['ldap'][38]="Criteris de cerca pels usuaris"; 
$LANG['ldap'][39]="Expert"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="Canviar"; 
$LANG['ldap'][42]="Cap directori seleccionat"; 
$LANG['ldap'][43]="No hi ha usuaris per a sincronitzar"; 
$LANG['ldap'][44]="Servidor per defecte"; 
$LANG['ldap'][45]="Acció quan un usuari es eliminat de LDAP"; 
$LANG['ldap'][46]="Eliminar els permisos i grups (dinàmics)"; 
$LANG['ldap'][47]="Enviar a la paperera"; 
$LANG['ldap'][48]="Usuari eliminat d'LDAP"; 
$LANG['ldap'][49]="Veure usuaris afegits des de"; 
$LANG['ldap'][50]="Veure usuaris actualitzats des de"; 
$LANG['ldap'][52]="Menys de"; 
$LANG['ldap'][53]="Més de"; 
$LANG['ldap'][54]="Activar el filtre per data"; 
$LANG['ldap'][55]="Desactivada el filtre per data"; 
$LANG['ldap'][56]="Setmanes"; 

$LANG['links'][1]="Enllaç o nom de fitxer"; 
$LANG['links'][4]="Tipus de materials associats"; 
$LANG['links'][6]="Tags vàlids"; 
$LANG['links'][7]="No hi ha enllaços definits"; 
$LANG['links'][9]="Contingut del fitxer"; 

$LANG['log'][1]="sistema"; 
$LANG['log'][16]="planificació"; 
$LANG['log'][18]="components"; 
$LANG['log'][20]="Afegir l'element"; 
$LANG['log'][21]="actualització de l'element"; 
$LANG['log'][22]="esborrat de l'element"; 
$LANG['log'][23]="reposició de l'element"; 
$LANG['log'][24]="purga de l'element"; 
$LANG['log'][26]="desconnexió de l'element"; 
$LANG['log'][27]="connexió de l'element"; 
$LANG['log'][28]="modificació de components"; 
$LANG['log'][29]="aprovació/refusat de la solució"; 
$LANG['log'][30]="Associació d'un tipus"; 
$LANG['log'][31]="esborrat d'un tipus"; 
$LANG['log'][32]="Afegit enllaç amb un element"; 
$LANG['log'][33]="esborrat d'enllaç amb un element"; 
$LANG['log'][34]="Afegir enllaç amb empresa"; 
$LANG['log'][35]="esborrat d'enllaç amb empresa"; 
$LANG['log'][40]="Connexió del IP"; 
$LANG['log'][41]="fallada de connexió"; 
$LANG['log'][42]="Reserva"; 
$LANG['log'][44]="Titulat"; 
$LANG['log'][45]="Correcta"; 
$LANG['log'][46]="Fallida"; 
$LANG['log'][48]="afegir usuari al grup"; 
$LANG['log'][49]="esborrat d'usuari en el grup"; 
$LANG['log'][55]="Connexió"; 
$LANG['log'][59]="Cron"; 
$LANG['log'][60]="desglobalització de l'ítem"; 
$LANG['log'][61]="afegit un usuari a l'entitat"; 
$LANG['log'][62]="esborrat d'un usuari de la entitat"; 
$LANG['log'][64]="modificació del camp"; 
$LANG['log'][65]="regla"; 
$LANG['log'][66]="Seguretat"; 
$LANG['log'][67]="modificació de les notes"; 
$LANG['log'][70]="afegit un port de xarxa"; 
$LANG['log'][71]="afegits varis ports de xarxa"; 
$LANG['log'][73]="eliminació d'un port de xarxa"; 
$LANG['log'][74]="eliminació de varis ports de xarxa"; 
$LANG['log'][75]="port de xarxa mogut"; 
$LANG['log'][77]="vlan assignada a port de xarxa"; 
$LANG['log'][78]="assignació d'una VLAN a varis ports de xarxa"; 
$LANG['log'][79]="vlan no assignada a port de xarxa"; 
$LANG['log'][80]="treta l'assignació de vlan a varis ports de la xarxa"; 
$LANG['log'][82]="afegit de la versió"; 
$LANG['log'][83]="modificació de la versió"; 
$LANG['log'][84]="eliminació de la versió"; 
$LANG['log'][85]="afegit de la llicència"; 
$LANG['log'][86]="modificació de la llicència"; 
$LANG['log'][87]="eliminació de la llicència"; 
$LANG['log'][88]="afegint cartutxos"; 
$LANG['log'][89]="afegint consumibles"; 
$LANG['log'][90]="exclusió d'un cartutx"; 
$LANG['log'][91]="exclusió d'un consumible"; 
$LANG['log'][92]="restauració d'un cartutx"; 
$LANG['log'][93]="restauració d'un consumible"; 
$LANG['log'][94]="actualització de cartutxos"; 
$LANG['log'][95]="Instal·lació d'un cartutx"; 
$LANG['log'][96]="desinstal·lació de cartutxos"; 
$LANG['log'][97]="alliberació d'un consumible per l'usuari"; 
$LANG['log'][98]="adjuntar un element"; 
$LANG['log'][99]="Modificació d'un element"; 
$LANG['log'][100]="eliminació d'un element"; 

$LANG['login'][0]="Última connexió"; 
$LANG['login'][1]="Tornar a ingressar"; 
$LANG['login'][2]="LDAP"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Accés denegat"; 
$LANG['login'][6]="Usuari"; 
$LANG['login'][7]="Contrasenya"; 
$LANG['login'][8]="Usuari o contrasenya buits"; 
$LANG['login'][9]="Encara no està autenticat"; 
$LANG['login'][10]="Autenticació"; 
$LANG['login'][11]="Usuari no autoritzat a connectar-se"; 
$LANG['login'][12]="Usuari o contrasenya erronis"; 
$LANG['login'][13]="Contrasenya buida"; 
$LANG['login'][14]="Usuari desconegut"; 
$LANG['login'][15]="Usuari no trobat o trobats varis usuaris"; 
$LANG['login'][16]="Fallada a l'autenticació LDAP"; 
$LANG['login'][18]="Base interna de GLPI"; 
$LANG['login'][20]="No, tens accés a aquest aplicatiu. El teu compte ha sigut desactivat o eliminat."; 
$LANG['login'][21]="Prova de connexió amb el servidor IMAP/POP"; 
$LANG['login'][22]="Prova correcta"; 
$LANG['login'][23]="Prova fallida"; 
$LANG['login'][24]="Data de l'última actualització"; 
$LANG['login'][25]="No té permisos per a connectar-se a aquesta aplicació"; 
$LANG['login'][26]="Ha d'activar Javascipt al seu navegador"; 
$LANG['login'][27]="Has d'autoritzar les cookies per accedir-hi a l'aplicatiu"; 
$LANG['login'][30]="Canviar el mètode d'identificació"; 
$LANG['login'][31]="Identificació sobre LDAP"; 
$LANG['login'][32]="Identificació sobre la base de dades de GLPI"; 
$LANG['login'][33]="Identificació sobre el servidor POP/IMAP"; 

$LANG['mailgate'][0]="Gateway de correu"; 
$LANG['mailgate'][2]="Recuperar ara"; 
$LANG['mailgate'][3]="Nombre de missatges disponibles i recuperats"; 
$LANG['mailgate'][4]="L'extensió mbstring no està disponible. Tingui compte amb els jocs de caràcters que utilitzi"; 
$LANG['mailgate'][5]="Arxiu adjunt no vàlid"; 
$LANG['mailgate'][6]="Arxiu adjunt massa gran"; 
$LANG['mailgate'][7]="Servidor de correu POP: grandària màxima de cada arxiu adjunt (0 : sense límit)"; 
$LANG['mailgate'][9]="El seu correu no pot ser tractat.\n Contactar amb l'administrador si el problema continua"; 
$LANG['mailgate'][10]="Correu rebutjat"; 
$LANG['mailgate'][11]="Procés d'importació de correus electrònic"; 
$LANG['mailgate'][12]="No es pot associar el correu electrònic a una entitat"; 
$LANG['mailgate'][13]="Raó del rebuig"; 
$LANG['mailgate'][14]="L'adreça de correu no existeix. Impossible importar-la"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="-----------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Seguiment(s) efectuat(s)"; 
$LANG['mailing'][5]="Descripció de la incidència"; 
$LANG['mailing'][10]="Nou seguiment per aquesta incidència"; 
$LANG['mailing'][12]="Assignació d'incidència"; 
$LANG['mailing'][14]="Canvi de categoria de la incidència"; 
$LANG['mailing'][15]="Canvi de prioritat de la incidència"; 
$LANG['mailing'][17]="Canvi de material de la incidència"; 
$LANG['mailing'][18]="Modificació de l'autor de la incidència"; 
$LANG['mailing'][19]="Nova reserva"; 
$LANG['mailing'][20]="Modificació del grup de la incidència"; 
$LANG['mailing'][21]="Canvi de l'origen de la incidencia"; 
$LANG['mailing'][23]="Modificació de reserva"; 
$LANG['mailing'][26]="Document afegit :"; 
$LANG['mailing'][27]="Modificació de l'estat de la incidència"; 
$LANG['mailing'][29]="Anular la reserva"; 
$LANG['mailing'][30]="Modificació d'incidencia"; 
$LANG['mailing'][31]="Aquest es el missatge de prova d'enviament d'email"; 
$LANG['mailing'][32]="Prova de mail"; 
$LANG['mailing'][33]="Alerta de cartutxos"; 
$LANG['mailing'][35]="Llindar d'alarma arribat pel tipus de consumibles:"; 
$LANG['mailing'][36]="Alerta de consumibles"; 
$LANG['mailing'][37]="Contracte ingressat en període de preavís:"; 
$LANG['mailing'][39]="Alerta de contractes"; 
$LANG['mailing'][40]="Material arribat a caducitat de garantia:"; 
$LANG['mailing'][41]="Alerta de dades financeres"; 
$LANG['mailing'][42]="Canvi del cost per hora"; 
$LANG['mailing'][43]="Canvi del cost fixe"; 
$LANG['mailing'][44]="Canvi del cost del material"; 
$LANG['mailing'][45]="Modificació del títol de la incidència"; 
$LANG['mailing'][46]="Modificació de la descripció de la incidència"; 
$LANG['mailing'][47]="Error a l'enviament de l'email"; 
$LANG['mailing'][48]="Canvi de la data d'apertura"; 
$LANG['mailing'][49]="Canvi de la data de tancament"; 
$LANG['mailing'][50]="Modificació del receptor de la incidència"; 
$LANG['mailing'][51]="Llicencia expirada :"; 
$LANG['mailing'][53]="Canvi de la solució"; 
$LANG['mailing'][54]="Data d'expiració"; 
$LANG['mailing'][100]="No hi ha categoria assignada"; 
$LANG['mailing'][101]="Seguiment per email activat"; 
$LANG['mailing'][102]="Seguiment per email desactivat"; 
$LANG['mailing'][104]="Duració de la incidència"; 
$LANG['mailing'][105]="No assignada"; 
$LANG['mailing'][107]="No hi ha material involucrat"; 
$LANG['mailing'][109]="Sense grup"; 
$LANG['mailing'][110]="Email no vàlit"; 
$LANG['mailing'][113]="Models de notificació"; 
$LANG['mailing'][114]="Cos del missatge"; 
$LANG['mailing'][115]="Cos del correu"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Correu electrònic"; 
$LANG['mailing'][119]="Event"; 
$LANG['mailing'][120]="Mode de notificació"; 
$LANG['mailing'][121]="Destinataris"; 
$LANG['mailing'][122]="Tasca(es) executada(es)"; 
$LANG['mailing'][123]="Incident resolt"; 
$LANG['mailing'][124]="Afegir una nova traducció"; 
$LANG['mailing'][125]="Traducció per defecte"; 
$LANG['mailing'][126]="Plantilla de traducció"; 
$LANG['mailing'][127]="Tancament dels incidents"; 
$LANG['mailing'][128]="deixar el camp buit per a una generació a partir de l'HTML"; 
$LANG['mailing'][129]="Supressió d'un incident"; 
$LANG['mailing'][130]="De"; 
$LANG['mailing'][131]="Destinatari"; 
$LANG['mailing'][132]="Capçalera del correu"; 
$LANG['mailing'][133]="Eliminar correu(s)"; 
$LANG['mailing'][134]="Actualització de seguiment"; 
$LANG['mailing'][135]="Esborrat de seguiment"; 
$LANG['mailing'][136]="Fi de la reserva"; 
$LANG['mailing'][137]="Usuari del material"; 
$LANG['mailing'][138]="Llistat dels tags disponibles"; 
$LANG['mailing'][139]="Etiqueta"; 
$LANG['mailing'][140]="TAG"; 
$LANG['mailing'][141]="Seguiments"; 
$LANG['mailing'][142]="Tasca"; 
$LANG['mailing'][143]="Validacions"; 
$LANG['mailing'][144]="Històric"; 
$LANG['mailing'][145]="Llista de valors"; 
$LANG['mailing'][146]="valor únic"; 
$LANG['mailing'][147]="Valor(s) possible(s)"; 

$LANG['Menu'][0]="Ordinadors"; 
$LANG['Menu'][1]="Elements de xarxa"; 
$LANG['Menu'][2]="Impressores"; 
$LANG['Menu'][3]="Monitors"; 
$LANG['Menu'][4]="Programari"; 
$LANG['Menu'][5]="Seguiment(s)"; 
$LANG['Menu'][6]="Informes"; 
$LANG['Menu'][11]="Preferències"; 
$LANG['Menu'][12]="Manteniment"; 
$LANG['Menu'][13]="Estadístiques"; 
$LANG['Menu'][14]="Usuaris"; 
$LANG['Menu'][15]="Administració"; 
$LANG['Menu'][16]="Perifèrics"; 
$LANG['Menu'][17]="Reserves"; 
$LANG['Menu'][18]="Utilitats"; 
$LANG['Menu'][19]="Base de coneixement"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Cartutxos"; 
$LANG['Menu'][22]="Contactes"; 
$LANG['Menu'][23]="Proveïdors"; 
$LANG['Menu'][24]="Dades financeres"; 
$LANG['Menu'][25]="Contractes"; 
$LANG['Menu'][26]="Gestió"; 
$LANG['Menu'][27]="Documents"; 
$LANG['Menu'][28]="Estats"; 
$LANG['Menu'][29]="Planificació"; 
$LANG['Menu'][30]="Logs"; 
$LANG['Menu'][31]="CAU (Centre d'Atenció als Usuaris)"; 
$LANG['Menu'][32]="Consumibles"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telèfon(s)"; 
$LANG['Menu'][35]="Perfils"; 
$LANG['Menu'][36]="Grups"; 
$LANG['Menu'][37]="Entitats"; 
$LANG['Menu'][38]="Inventari"; 
$LANG['Menu'][39]="Gateways de correu"; 
$LANG['Menu'][40]="Marcadors"; 
$LANG['Menu'][41]="Permisos"; 

$LANG['monitors'][14]="Micròfon"; 
$LANG['monitors'][15]="Altaveus"; 
$LANG['monitors'][18]="Opcions"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Grandària"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Peanya"; 

$LANG['networking'][4]="Port de xarxa"; 
$LANG['networking'][5]="RAM (MB)"; 
$LANG['networking'][6]="Ports de xarxa"; 
$LANG['networking'][13]="port(s) de xarxa trobat(s)"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Connectat a"; 
$LANG['networking'][19]="Afegir un port..."; 
$LANG['networking'][21]="Numero de port"; 
$LANG['networking'][25]="sobre"; 
$LANG['networking'][37]="Port(s) trobat(s)"; 
$LANG['networking'][44]="El port"; 
$LANG['networking'][46]="Afegir varis ports..."; 
$LANG['networking'][47]="De"; 
$LANG['networking'][48]="A"; 
$LANG['networking'][51]="Boca de xarxa"; 
$LANG['networking'][55]="Associar una VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Escolleix una adreça MAC a la llista o especifiqui-la aquí sota"; 
$LANG['networking'][58]="Eliminar una VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Màscara"; 
$LANG['networking'][61]="Subxarxa"; 

$LANG['ocsconfig'][1]="Usuaris de la base de dades OCSNG"; 
$LANG['ocsconfig'][2]="Servidor OCSNG"; 
$LANG['ocsconfig'][3]="Contrasenya d'usuari OCSweb"; 
$LANG['ocsconfig'][4]="Nom de la base de dades OCSNG"; 
$LANG['ocsconfig'][5]="Opcions d'importació"; 
$LANG['ocsconfig'][6]="Ignorar la importació des d'OCSNG"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Excloure les següents etiquetes (separador $, res per ningú)"; 
$LANG['ocsconfig'][10]="Importació global"; 
$LANG['ocsconfig'][11]="No importar"; 
$LANG['ocsconfig'][12]="Importació única"; 
$LANG['ocsconfig'][13]="Importació única: tot s'importa tal com està"; 
$LANG['ocsconfig'][14]="Importació global: tot s'importa però el material es gestiona de forma global (sense duplicats)"; 
$LANG['ocsconfig'][15]="No importar: GLPI no importarà aquests elements"; 
$LANG['ocsconfig'][16]="Estat predeterminat"; 
$LANG['ocsconfig'][17]="Limitar l'importació als tags següents (separador $; res, per a tots)"; 
$LANG['ocsconfig'][18]="Asseguri's d'haver gestionat correctament els duplicats en OCSNG"; 
$LANG['ocsconfig'][19]="Importació única basada al numero de serie"; 
$LANG['ocsconfig'][27]="Informació general d'ordinadors"; 
$LANG['ocsconfig'][36]="Modems"; 
$LANG['ocsconfig'][37]="Ports"; 
$LANG['ocsconfig'][38]="Utilitzar el diccionari de programari d'OCS"; 
$LANG['ocsconfig'][39]="TAG OCSNG"; 
$LANG['ocsconfig'][40]="Quantitat d'elements a sincronitzar mitjançant cron"; 
$LANG['ocsconfig'][41]="Registro de Windows"; 
$LANG['ocsconfig'][43]="Informació administrativa d'OCSNG"; 
$LANG['ocsconfig'][48]="Comportament durant la desconnexió"; 
$LANG['ocsconfig'][49]="Paperera"; 
$LANG['ocsconfig'][50]="Eliminació"; 
$LANG['ocsconfig'][52]="Enllaç automàtic d'ordinadors"; 
$LANG['ocsconfig'][53]="Activar els enllaços automàtics"; 
$LANG['ocsconfig'][54]="Criteris d'existència d'un ordinador"; 
$LANG['ocsconfig'][55]="Buscar els ordinadors GLPI amb l'estat"; 
$LANG['ocsconfig'][56]="ple"; 
$LANG['ocsconfig'][57]="igual"; 
$LANG['ocsconfig'][58]="L'enllaç uneix automàticament un ordinador GLPI amb un d'OCS.<br>Aquesta opció es té en compte durant l'enllaç manual i els script de sincronització."; 
$LANG['ocsconfig'][59]="URL de la consola d'OCSNG"; 

$LANG['ocsng'][0]="Inventari OCS NG"; 
$LANG['ocsng'][1]="Sincronització d'ordinadors ja importats"; 
$LANG['ocsng'][2]="Importació d'ordinadors nous"; 
$LANG['ocsng'][3]="Neteja d'enllaços GLPI/OCSNG"; 
$LANG['ocsng'][4]="Enllaçar ordinadors nous a ordinadors existents"; 
$LANG['ocsng'][5]="Importar ordinadors nous"; 
$LANG['ocsng'][6]="Actualització automàtica"; 
$LANG['ocsng'][7]="Importat des d'OCSNG"; 
$LANG['ocsng'][8]="Importació correcta"; 
$LANG['ocsng'][9]="No hi ha nous ordinadors per a importar"; 
$LANG['ocsng'][10]="Ordinadors actualitzats a OCSNG"; 
$LANG['ocsng'][11]="Actualització d'ordinadors"; 
$LANG['ocsng'][12]="No hi ha nous ordinadors per a actualitzar"; 
$LANG['ocsng'][13]="Data d'importació a GLPI"; 
$LANG['ocsng'][14]="Data de l'últim inventari OCSNG"; 
$LANG['ocsng'][15]="No hi ha camps bloquejats"; 
$LANG['ocsng'][16]="Camps marcats"; 
$LANG['ocsng'][18]="Connexió correcta amb la base de dades OCSNG"; 
$LANG['ocsng'][19]="Versió i configuració OCSNG vàlides"; 
$LANG['ocsng'][20]="Versió d'OCSNG no vàlida: es necessita RC3"; 
$LANG['ocsng'][21]="No es va assolir la connexió amb la base de dades OCSNG"; 
$LANG['ocsng'][22]="Atenció! Les dades importades (vegi la seva configuració) reemplaçaran als existents"; 
$LANG['ocsng'][23]="Importació impossible, l'ordinador destí de GLPI ja està enllaçat a un element d'OCSNG"; 
$LANG['ocsng'][24]="Forçar la sincronització"; 
$LANG['ocsng'][26]="Esculli un servidor OCSNG"; 
$LANG['ocsng'][27]="No s'ha definit cap servidor OCS"; 
$LANG['ocsng'][29]="Servidor OCSNG"; 
$LANG['ocsng'][30]="Monitors bloquejats"; 
$LANG['ocsng'][32]="Perifèrics bloquejats"; 
$LANG['ocsng'][34]="Impressores bloquejades"; 
$LANG['ocsng'][36]="Entitat de destí"; 
$LANG['ocsng'][37]="Activar la vista preliminar"; 
$LANG['ocsng'][38]="Desactivar la vista preliminar"; 
$LANG['ocsng'][40]="Cumpleix la regla?"; 
$LANG['ocsng'][41]="Mode d'importació manual"; 
$LANG['ocsng'][42]="La configuració d'OCSNG no es correcta. Deu activar TRACE_DELETED."; 
$LANG['ocsng'][43]="Accés denegat a la base de dades d'OCS. Has de tenir permís d'escriptura a hardware.CHECKSUM necessari."; 
$LANG['ocsng'][44]="Accés denegat a la base de dades d'OCS. Has de tenir permís per eliminar a deleted_equiv."; 
$LANG['ocsng'][45]="ID OCS"; 
$LANG['ocsng'][46]="Eliminar a l'OCSNG"; 
$LANG['ocsng'][47]="Enllaçat amb un ordinador d'OCSNG"; 
$LANG['ocsng'][48]="L'ordinador ha canviat d'identificador OCSNG (ID)"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="IPs bloquejades"; 
$LANG['ocsng'][52]="Programari bloquejat"; 
$LANG['ocsng'][54]="Material llençat a la paperera per la sincronització OCS"; 
$LANG['ocsng'][55]="Volum(s) bloquejat(s)"; 
$LANG['ocsng'][57]="Interfície OCSNG"; 

$LANG['pager'][1]="fins a"; 
$LANG['pager'][2]="des de"; 
$LANG['pager'][3]="de"; 
$LANG['pager'][4]="Presentar"; 
$LANG['pager'][5]="elements"; 

$LANG['peripherals'][18]="Marca"; 
$LANG['peripherals'][31]="Gestió global"; 
$LANG['peripherals'][32]="Gestió individual"; 
$LANG['peripherals'][33]="Tipus de gestió"; 

$LANG['phones'][18]="Marca"; 
$LANG['phones'][36]="Alimentació"; 
$LANG['phones'][38]="Casc"; 
$LANG['phones'][39]="Altaveu"; 
$LANG['phones'][40]="Quantitat de línies"; 

$LANG['planning'][0]="El tècnic sol.licitat ja té un servei previst per a aquest horari."; 
$LANG['planning'][1]="Error en l'ingrés de les seves dates. La data d'inici és posterior a la data final"; 
$LANG['planning'][5]="Dia"; 
$LANG['planning'][6]="Setmana"; 
$LANG['planning'][8]="Servei"; 
$LANG['planning'][9]="Per"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Descarregar calendari en format Ical"; 
$LANG['planning'][13]="Sincronització Webcal://"; 
$LANG['planning'][14]="Mes"; 
$LANG['planning'][15]="La seva planificació"; 
$LANG['planning'][16]="Informació"; 
$LANG['planning'][17]="Pendent"; 
$LANG['planning'][18]="Acabat"; 

$LANG['plugins'][0]="Llista de plugins"; 
$LANG['plugins'][2]="Instal·lat / no configurat"; 
$LANG['plugins'][3]="Instal·lat / no activat"; 
$LANG['plugins'][4]="Error / a netejar"; 
$LANG['plugins'][5]="Funció(ns) inexistent(s)"; 
$LANG['plugins'][6]="A actualitzar"; 
$LANG['plugins'][7]="Cap plugin instal·lat"; 
$LANG['plugins'][8]="Veure llistats de plugins"; 
$LANG['plugins'][9]="Autors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Serie"; 
$LANG['printers'][15]="Paral·lel"; 
$LANG['printers'][18]="Ports"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Inalambrica"; 
$LANG['printers'][30]="Comptador de pàgina inicial"; 
$LANG['printers'][31]="Pàgines impreses"; 

$LANG['profiles'][0]="Permís global"; 
$LANG['profiles'][1]="Permís local"; 
$LANG['profiles'][2]="Interfície associada al perfil"; 
$LANG['profiles'][4]="Afegir seguiment als incidents dels meus grups"; 
$LANG['profiles'][5]="Obrir una incidència"; 
$LANG['profiles'][6]="Afegir un seguiment als incidents (autor)"; 
$LANG['profiles'][7]="Veure les incidències"; 
$LANG['profiles'][8]="Veure tot el seguiment (públic i privat)"; 
$LANG['profiles'][9]="Veure el seguiment públic"; 
$LANG['profiles'][10]="Lectura"; 
$LANG['profiles'][11]="Escriptura"; 
$LANG['profiles'][12]="Sense Accés"; 
$LANG['profiles'][13]="Perfil predeterminat"; 
$LANG['profiles'][14]="Esborrar una incidència"; 
$LANG['profiles'][15]="Afegir un seguiment a totes les incidències"; 
$LANG['profiles'][16]="Estar a càrrec d'una incidència"; 
$LANG['profiles'][17]="Treure un incident"; 
$LANG['profiles'][18]="Modificar una incidència"; 
$LANG['profiles'][19]="Assignar una incidència"; 
$LANG['profiles'][20]="Veure planificació personal"; 
$LANG['profiles'][21]="Veure totes les planificacions"; 
$LANG['profiles'][22]="Perfil"; 
$LANG['profiles'][23]="Administració de reserves"; 
$LANG['profiles'][24]="Actualització de contrasenya"; 
$LANG['profiles'][26]="Veure les incidències creades per grup associat"; 
$LANG['profiles'][27]="Veure els materials dels grups associats"; 
$LANG['profiles'][28]="Recursiu"; 
$LANG['profiles'][29]="Dinàmic"; 
$LANG['profiles'][30]="Veure la informació OCSNG"; 
$LANG['profiles'][31]="Sincronització manual amb OCSNG"; 
$LANG['profiles'][32]="Veure les incidències assignades (personal + grup associat)"; 
$LANG['profiles'][33]="No s'han trobat usuaris"; 
$LANG['profiles'][34]="Llegenda"; 
$LANG['profiles'][35]="Modificar tots els seguiments"; 
$LANG['profiles'][36]="Veure la planificació de les persones dels meus grups"; 
$LANG['profiles'][37]="Entitat per defecte"; 
$LANG['profiles'][38]="Visibilitat"; 
$LANG['profiles'][39]="Assignació"; 
$LANG['profiles'][40]="Actualitzar"; 
$LANG['profiles'][41]="Crear"; 
$LANG['profiles'][42]="Associació"; 
$LANG['profiles'][43]="Mètode d'autenticació i sincronització dels usuaris"; 
$LANG['profiles'][44]="Modificar la prioritat"; 
$LANG['profiles'][45]="Afegir una tasca a tots els incidents"; 
$LANG['profiles'][46]="Editar totes les tasques"; 
$LANG['profiles'][47]="Afegir usuaris d'una font externa"; 
$LANG['profiles'][48]="Sol·licitud de validació d'incident"; 
$LANG['profiles'][49]="Validar un incident"; 

$LANG['registry'][1]="Secció"; 
$LANG['registry'][2]="Ruta"; 
$LANG['registry'][3]="Clau/valor"; 
$LANG['registry'][4]="Claus de registres trobats"; 
$LANG['registry'][5]="No s'ha trobat cap clau del Registre de Windows"; 
$LANG['registry'][6]="Nom OCSNG"; 

$LANG['reminder'][0]="Notes personals"; 
$LANG['reminder'][1]="Notes públiques"; 
$LANG['reminder'][6]="Nova nota"; 
$LANG['reminder'][9]="Text"; 
$LANG['reminder'][12]="Afegir a la llista"; 
$LANG['reminder'][15]="Sense títol"; 
$LANG['reminder'][16]="Notes globals"; 

$LANG['reports'][0]="Seleccionar un informe"; 
$LANG['reports'][4]="Llista del material sota contracte"; 
$LANG['reports'][11]="Material sota contracte"; 
$LANG['reports'][12]="Tipus de material"; 
$LANG['reports'][13]="Dates"; 
$LANG['reports'][15]="Mostrar informe"; 
$LANG['reports'][19]="Contacte"; 
$LANG['reports'][26]="Informe predeterminat"; 
$LANG['reports'][27]="Per contractes"; 
$LANG['reports'][28]="Per anys"; 
$LANG['reports'][33]="Informe de xarxa"; 
$LANG['reports'][36]="Dispositius connectat"; 
$LANG['reports'][37]="Boques"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Per lloc"; 
$LANG['reports'][41]="Per switch"; 
$LANG['reports'][42]="Per boca"; 
$LANG['reports'][46]="port del switch"; 
$LANG['reports'][47]="Port del dispositiu"; 
$LANG['reports'][49]="Informe de xarxa per switch"; 
$LANG['reports'][51]="Informe de xarxa per boca"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Informe de xarxa per lloc"; 
$LANG['reports'][57]="Llista de materials"; 
$LANG['reports'][58]="Informe dels materials per anys"; 
$LANG['reports'][60]="Data d'obertura"; 
$LANG['reports'][61]="Data de tancament"; 
$LANG['reports'][62]="Dades financeres de material inventariat"; 
$LANG['reports'][63]="Altres dades financeres (llicencies, consumibles, cartutxos)"; 
$LANG['reports'][64]="Data de resolució"; 

$LANG['reservation'][1]="Material reservable"; 
$LANG['reservation'][2]="Material no disponible temporalment"; 
$LANG['reservation'][3]="Fes clic per a que quedi no disponible"; 
$LANG['reservation'][5]="Fes clic per a que quedi disponible"; 
$LANG['reservation'][6]="No autoritzar el préstec"; 
$LANG['reservation'][7]="Autoritzar el préstec"; 
$LANG['reservation'][8]="Reserva"; 
$LANG['reservation'][9]="Reservar un material"; 
$LANG['reservation'][16]="Fins a"; 
$LANG['reservation'][17]="Des de"; 
$LANG['reservation'][18]="El material sol.licitat ja està reservat per a aquest horari."; 
$LANG['reservation'][20]="Tornar al calendari"; 
$LANG['reservation'][21]="Veure les reserves"; 
$LANG['reservation'][22]="Modificar el comentari"; 
$LANG['reservation'][25]="Tots els materials en préstec"; 
$LANG['reservation'][27]="Periodicitat"; 
$LANG['reservation'][28]="Per setmana"; 
$LANG['reservation'][29]="Per dia"; 
$LANG['reservation'][30]="vegades"; 
$LANG['reservation'][31]="Per"; 
$LANG['reservation'][35]="Reserves en curs i futures"; 
$LANG['reservation'][36]="Reserves passades"; 
$LANG['reservation'][37]="No hi ha reserves"; 
$LANG['reservation'][38]="Està segur de voler tornar aquest element no reservable?"; 
$LANG['reservation'][39]="Això eliminarà totes les reserves en curs."; 
$LANG['reservation'][40]="Equips amb reserva que expiren avui"; 

$LANG['rulesengine'][0]="és"; 
$LANG['rulesengine'][1]="no es"; 
$LANG['rulesengine'][2]="conté"; 
$LANG['rulesengine'][3]="no conté"; 
$LANG['rulesengine'][4]="comença per"; 
$LANG['rulesengine'][5]="acabat per"; 
$LANG['rulesengine'][6]="Criteris"; 
$LANG['rulesengine'][7]="Accions"; 
$LANG['rulesengine'][8]="Gestió de regles"; 
$LANG['rulesengine'][9]="Tipus d'emparellament"; 
$LANG['rulesengine'][10]="Posició"; 
$LANG['rulesengine'][11]="Tipus d'acció"; 
$LANG['rulesengine'][12]="Camps"; 
$LANG['rulesengine'][13]="Valor"; 
$LANG['rulesengine'][14]="Condició"; 
$LANG['rulesengine'][15]="Motiu"; 
$LANG['rulesengine'][16]="Criteri"; 
$LANG['rulesengine'][17]="Regles"; 
$LANG['rulesengine'][18]="Regles d'assignació d'un ordinador a una entitat"; 
$LANG['rulesengine'][19]="Regles d'assignació d'entitat i permisos a partir del directori"; 
$LANG['rulesengine'][20]="Regles heretades"; 
$LANG['rulesengine'][21]="Regles de sub-entitats"; 
$LANG['rulesengine'][22]="Assignar"; 
$LANG['rulesengine'][23]="Regles locals"; 
$LANG['rulesengine'][24]="Elecció del tipus de regla"; 
$LANG['rulesengine'][25]="Nom de l'ordinador"; 
$LANG['rulesengine'][26]="L'expressió regular es verifica"; 
$LANG['rulesengine'][27]="L'expressió regular no es verifica"; 
$LANG['rulesengine'][28]="Regles de negoci pel seguiment"; 
$LANG['rulesengine'][29]="Llista de regles"; 
$LANG['rulesengine'][30]="Acció"; 
$LANG['rulesengine'][33]="Diccionari de títols"; 
$LANG['rulesengine'][35]="Diccionari de programari"; 
$LANG['rulesengine'][36]="Diccionari dels fabricants"; 
$LANG['rulesengine'][37]="Regles d'assignació de categoria als programes"; 
$LANG['rulesengine'][38]="Tornar a calcular"; 
$LANG['rulesengine'][40]="la categoria"; 
$LANG['rulesengine'][41]="Validació"; 
$LANG['rulesengine'][42]="I"; 
$LANG['rulesengine'][43]="O"; 
$LANG['rulesengine'][45]="Assigna el valor de l'expressió regular"; 
$LANG['rulesengine'][46]="Assignar: IP de l'equip"; 
$LANG['rulesengine'][47]="Assignar: nom d'equip + domini"; 
$LANG['rulesengine'][48]="Assignar material"; 
$LANG['rulesengine'][49]="Assignar: material per l'adreça MAC"; 
$LANG['rulesengine'][50]="Diccionari dels models d'ordinadors"; 
$LANG['rulesengine'][51]="Diccionari dels models de monitors"; 
$LANG['rulesengine'][52]="Diccionari dels models de telèfons"; 
$LANG['rulesengine'][53]="Diccionari dels models de perifèrics"; 
$LANG['rulesengine'][54]="Diccionari dels models d'impressores"; 
$LANG['rulesengine'][55]="Diccionari de models d'electrònica de xarxa"; 
$LANG['rulesengine'][56]="Models"; 
$LANG['rulesengine'][60]="Diccionari dels tipus d'ordinadors"; 
$LANG['rulesengine'][61]="Diccionari dels tipus de monitors"; 
$LANG['rulesengine'][62]="Diccionari dels tipus de telèfons"; 
$LANG['rulesengine'][63]="Diccionari dels tipus de perifèrics"; 
$LANG['rulesengine'][64]="Diccionari dels tipus d'impressores"; 
$LANG['rulesengine'][65]="Diccionari de tipus d'electrònica de xarxa"; 
$LANG['rulesengine'][66]="Tipus"; 
$LANG['rulesengine'][67]="Diccionari de S.O."; 
$LANG['rulesengine'][68]="Diccionari dels service packs"; 
$LANG['rulesengine'][69]="Diccionari de les versions"; 
$LANG['rulesengine'][70]="Regles d'assignació d'un incident creat per correu"; 
$LANG['rulesengine'][76]="Retocar diccionari"; 
$LANG['rulesengine'][77]="Diccionaris"; 
$LANG['rulesengine'][78]="Versió"; 
$LANG['rulesengine'][79]="Afegir el resultat de l'expressió regular"; 
$LANG['rulesengine'][80]="Diccionari general"; 
$LANG['rulesengine'][81]="Resultat de la regla"; 
$LANG['rulesengine'][82]="Detall del resultat"; 
$LANG['rulesengine'][83]="Pot assignar el resultat d'una expressió regular utilitzant la cadena #0"; 
$LANG['rulesengine'][84]="Provar el motor de regles"; 
$LANG['rulesengine'][85]="Resultat de l'expressió regular"; 
$LANG['rulesengine'][86]="Reassignació de categoria del programa a l'esborrar l'actual"; 
$LANG['rulesengine'][87]="Material llençat a la paperera pel diccionari GLPI"; 
$LANG['rulesengine'][90]="Tractament en curs..."; 
$LANG['rulesengine'][91]="Tractament acabat."; 
$LANG['rulesengine'][92]="Tinguis cura abans d'executar el diccionari"; 
$LANG['rulesengine'][93]="Avis! Aquesta operació pot portar programari fusionat a la paperera.<br>Avisi als usuaris."; 
$LANG['rulesengine'][94]="FUSIÓ"; 
$LANG['rulesengine'][95]="Escolleix un fabricant"; 
$LANG['rulesengine'][96]="Repetir el diccionari per a fabricant(s)<br> (------ = Tot)"; 
$LANG['rulesengine'][97]="Cap element per a comprovar"; 
$LANG['rulesengine'][100]="Informacions sobre la cache"; 
$LANG['rulesengine'][102]="Nom de la regla"; 
$LANG['rulesengine'][103]="Objectes a cache"; 
$LANG['rulesengine'][104]="Valor original"; 
$LANG['rulesengine'][105]="Valor modificat"; 
$LANG['rulesengine'][106]="Sense canvis"; 
$LANG['rulesengine'][107]="Inactiu"; 
$LANG['rulesengine'][108]="original"; 
$LANG['rulesengine'][110]="Assignació de drets"; 
$LANG['rulesengine'][111]="Assignació d'entitats"; 
$LANG['rulesengine'][112]="Drets i assignació d'entitats"; 
$LANG['rulesengine'][120]="El motor es para quan es verifiqui una de les regles."; 
$LANG['rulesengine'][121]="El motor executa totes les regles."; 
$LANG['rulesengine'][122]="El motor passa el resultat d'una regla a les següents."; 
$LANG['rulesengine'][130]="Entitat des de LDAP"; 
$LANG['rulesengine'][131]="Entitat des de TAG"; 
$LANG['rulesengine'][132]="Ignorar la importació"; 
$LANG['rulesengine'][133]="Entitat del domini"; 
$LANG['rulesengine'][134]="Rebutjar correu (sense resposta)"; 
$LANG['rulesengine'][135]="Rebutjar correu (amb resposta)"; 
$LANG['rulesengine'][138]="Criteris LDAP"; 
$LANG['rulesengine'][140]="Afegir criteri"; 
$LANG['rulesengine'][142]="Llistat de correus no importats"; 
$LANG['rulesengine'][144]="Entitat des de perfil d'usuari"; 
$LANG['rulesengine'][145]="Usuari amb un únic perfil"; 
$LANG['rulesengine'][146]="Amb el perfil de l'usuari"; 
$LANG['rulesengine'][147]="Usuari amb un únic perfil"; 
$LANG['rulesengine'][148]="Domini correu electrònic conegut"; 
$LANG['rulesengine'][150]="Les regles que afecten a l'entitat estan desactivades"; 

$LANG['search'][0]="Buscar"; 
$LANG['search'][1]="per a tots"; 
$LANG['search'][2]="conté"; 
$LANG['search'][4]="Ordenat per"; 
$LANG['search'][8]="Data inicial"; 
$LANG['search'][9]="Data final"; 
$LANG['search'][10]="en"; 
$LANG['search'][11]="Elements visualitzats"; 
$LANG['search'][12]="Especificar una data de finalització"; 
$LANG['search'][15]="No s'han trobat elements"; 
$LANG['search'][16]="Almenys"; 
$LANG['search'][17]="Afegir un criteri de recerca"; 
$LANG['search'][18]="Esborrar un criteri de recerca"; 
$LANG['search'][19]="Afegir un criteri global de recerca"; 
$LANG['search'][20]="Esborrar un criteri global de recerca"; 

$LANG['setup'][0]="Títols"; 
$LANG['setup'][2]="Afegir un usuari GLPI"; 
$LANG['setup'][3]="Enllaç LDAP"; 
$LANG['setup'][4]="Tipus d'ordinadors"; 
$LANG['setup'][5]="Sistemes operatius"; 
$LANG['setup'][6]="Personalització"; 
$LANG['setup'][9]="Interfície de xarxa"; 
$LANG['setup'][10]="Visualitza l'ordre del cognom i nom"; 
$LANG['setup'][14]="Correu Electrònic"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Contrasenya"; 
$LANG['setup'][20]="Confirmar contrasenya"; 
$LANG['setup'][21]="Error: les dos contrasenyes no son idèntiques"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Seguiment privat per defecte"; 
$LANG['setup'][40]="Tasques predeterminades per defecte"; 
$LANG['setup'][41]="Idioma"; 
$LANG['setup'][42]="Tipus d'electrònica de xarxa"; 
$LANG['setup'][43]="Tipus d'impressores"; 
$LANG['setup'][44]="Tipus de monitors"; 
$LANG['setup'][45]="Tipus de caixa"; 
$LANG['setup'][46]="Valor predeterminat"; 
$LANG['setup'][47]="Tipus de gràfica per defecte"; 
$LANG['setup'][48]="Valors per defecte"; 
$LANG['setup'][62]="Selecciona la categoria"; 
$LANG['setup'][63]="Atenció, està a punt d'esborrar un títol usat per un o més elements."; 
$LANG['setup'][64]="Si confirma l'eliminació, als elements sota aquest títol els assignarà un valor NULL"; 
$LANG['setup'][65]="També pot reemplaçar totes les ocurrències d'aquest títol per altre:"; 
$LANG['setup'][67]="Autenticacions externes"; 
$LANG['setup'][69]="Tipus de perifèrics"; 
$LANG['setup'][70]="Configuració general"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Boca de xarxa"; 
$LANG['setup'][74]="No es pot eliminar aquest element perquè té sub-elements"; 
$LANG['setup'][75]="Sota de"; 
$LANG['setup'][79]="Categories d'incidències"; 
$LANG['setup'][80]="Tipus de tercer"; 
$LANG['setup'][81]="Assumptes de documents"; 
$LANG['setup'][82]="Tipus de contactes"; 
$LANG['setup'][83]="Estat dels materials"; 
$LANG['setup'][84]="Tipus de cartutxos"; 
$LANG['setup'][85]="Tipus de contractes"; 
$LANG['setup'][86]="Tipus de memòria RAM"; 
$LANG['setup'][87]="Categories Base de Coneixement"; 
$LANG['setup'][88]="Xarxa"; 
$LANG['setup'][89]="Domini"; 
$LANG['setup'][90]="VLANs"; 
$LANG['setup'][91]="Models d'ordinadors"; 
$LANG['setup'][92]="Tipus de consumibles"; 
$LANG['setup'][93]="Interfaces (disc dur, ...)"; 
$LANG['setup'][94]="Models de monitors"; 
$LANG['setup'][95]="Models de material de xarxa"; 
$LANG['setup'][96]="Models d'impressores"; 
$LANG['setup'][97]="Models de perifèrics"; 
$LANG['setup'][98]="Categoria de la tasca"; 
$LANG['setup'][99]="Codi d'oficina"; 
$LANG['setup'][100]="Nombre de codi"; 
$LANG['setup'][101]="Número màxim de tasques (execució externa)"; 
$LANG['setup'][102]="Nivell de logging"; 
$LANG['setup'][103]="1- Crític (Autenticacions errònies)"; 
$LANG['setup'][104]="2- Sever (No utilitzat)"; 
$LANG['setup'][105]="3- Important (Autenticacions correctes)"; 
$LANG['setup'][106]="4- Avisos (Creació, esborrat, seguiments)"; 
$LANG['setup'][107]="5- Complet (Tot)"; 
$LANG['setup'][109]="Temps de conservació dels registres dels sistemes, en dies (0=infinit)"; 
$LANG['setup'][110]="Mostrar les incidències noves a l'entrar al sistema"; 
$LANG['setup'][111]="Quantitat d'elements a mostrar per pàgina"; 
$LANG['setup'][112]="Quantitat màxima de caràcters per a cada element de la llista"; 
$LANG['setup'][113]="Idioma predeterminat"; 
$LANG['setup'][114]="Colors de les prioritats"; 
$LANG['setup'][115]="Llindar d'alarma predeterminat pels cartutxos i consumibles"; 
$LANG['setup'][116]="Assignar automàticament les incidències al responsable tècnic"; 
$LANG['setup'][117]="Autoritzar la consulta de la FAQ en forma anònima"; 
$LANG['setup'][118]="Text a la pàgina d'inici"; 
$LANG['setup'][119]="Configuració de la presentació"; 
$LANG['setup'][120]="Utilitzar Ajax"; 
$LANG['setup'][121]="Comodí Ajax"; 
$LANG['setup'][122]="Ajax - Quantitat màxima d'elements mostrats quan no es fa servir el comodí"; 
$LANG['setup'][123]="No utilitzar Ajax si el número d'elements es inferior a (0=mai)"; 
$LANG['setup'][124]="Inserció automàtica d'usuaris a partir de fonts externes d'autenticació"; 
$LANG['setup'][125]="... Des d'un origen extern"; 
$LANG['setup'][126]="Afegir directament un usuari d'una font externa"; 
$LANG['setup'][127]="Auto-completar camps de text amb Ajax"; 
$LANG['setup'][128]="Format de dates"; 
$LANG['setup'][129]="Mostrar els ID GLPI"; 
$LANG['setup'][130]="Temps en dies que es conservaran els registres d'aquesta tasca (0 per a infinit)"; 
$LANG['setup'][132]="Mostrar el nom complert a la lista desplegable"; 
$LANG['setup'][133]="Activar el mode OCSNG"; 
$LANG['setup'][134]="Mode OCSNG"; 
$LANG['setup'][135]="Normal"; 
$LANG['setup'][136]="Traducció"; 
$LANG['setup'][137]="Depurar"; 
$LANG['setup'][138]="Utilitzar GLPI en modo"; 
$LANG['setup'][139]="General"; 
$LANG['setup'][140]="Tipus"; 
$LANG['setup'][145]="S.O."; 
$LANG['setup'][147]="AJAX"; 
$LANG['setup'][148]="Interval pels horaris"; 
$LANG['setup'][149]="Número de decimals pels imports"; 
$LANG['setup'][150]="Format de número"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (per a les connexions no anònimes)"; 
$LANG['setup'][156]="Pass (per a les connexions no anònimes)"; 
$LANG['setup'][157]="L'extensió LDAP del seu intèrpret PHP no està instal.lada"; 
$LANG['setup'][158]="Impossible utilitzar LDAP com origen de connexió externa"; 
$LANG['setup'][159]="Filtre de connexió"; 
$LANG['setup'][162]="Configuració IMAP/POP"; 
$LANG['setup'][164]="Nom de domini IMAP/POP <br>(email de tipus login@domini)"; 
$LANG['setup'][165]="L'extensió IMAP del seu intèrpret PHP no està instal.lada"; 
$LANG['setup'][166]="Impossible utilitzar IMAP/POP com origen de connexió externa"; 
$LANG['setup'][167]="Enllaç GLPI/LDAP"; 
$LANG['setup'][168]="Opcions de connexió"; 
$LANG['setup'][169]="Carpeta de correu (opcional, normalment INBOX)"; 
$LANG['setup'][170]="Cadena de connexió"; 
$LANG['setup'][171]="Port (opcional)"; 
$LANG['setup'][172]="Port LDAP (predeterminat=389)"; 
$LANG['setup'][174]="Servidor CAS"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Directori de base (opcional)"; 
$LANG['setup'][177]="Configuració CAS"; 
$LANG['setup'][178]="L'extensió CURL o DOMXML del seu intèrpret PHP no està instal·lat"; 
$LANG['setup'][179]="Impossible utilitzar CAS com origen de connexió externa"; 
$LANG['setup'][180]="Utilitzar TLS"; 
$LANG['setup'][181]="Funció ldap_start_tls inexistent"; 
$LANG['setup'][182]="URL de retorn al sortir de l'aplicació (logout)"; 
$LANG['setup'][185]="Registres en arxius (SQL, email, cron...)"; 
$LANG['setup'][186]="Fus horari"; 
$LANG['setup'][190]="Certificat x509"; 
$LANG['setup'][191]="Atributs de correu per a x509"; 
$LANG['setup'][192]="Activat"; 
$LANG['setup'][193]="Camp d'emmagatzematge de l'usuari al conjunt _SERVER"; 
$LANG['setup'][194]="Recuperació de dades complementaries utilitzant LDAP"; 
$LANG['setup'][195]="Mantenir estat"; 
$LANG['setup'][196]="Esborrar l'estat"; 
$LANG['setup'][197]="Copiar estat de l'ordinador"; 
$LANG['setup'][198]="Configurar estat"; 
$LANG['setup'][199]="Tregui el domini d'inici de sessió a la forma login@domain"; 
$LANG['setup'][200]="Infinit"; 
$LANG['setup'][201]="Configuració de la funció"; 
$LANG['setup'][202]="Utilitzar el seguiment per correu"; 
$LANG['setup'][203]="Mail de l'administrador"; 
$LANG['setup'][204]="Firma dels missatges"; 
$LANG['setup'][205]="Missatge de prova enviat a l'administrador"; 
$LANG['setup'][206]="Fracàs de l'enviament de missatge de prova a l'administrador"; 
$LANG['setup'][207]="Adreça de correu electrònic de resposta (si es necessari)"; 
$LANG['setup'][217]="La funció de mail PHP no existeix o està desactivada en el seu sistema"; 
$LANG['setup'][218]="Es imprescindible utilitzar un servidor SMTP"; 
$LANG['setup'][219]="Permetre les obertures d'incidents anònims (helpdesk.html)"; 
$LANG['setup'][221]="Data d'inici de l'exercici fiscal (dia i mes)"; 
$LANG['setup'][223]="Límit d'horaris per a la planificació"; 
$LANG['setup'][227]="URL de base utilitzat"; 
$LANG['setup'][228]="Camp de login"; 
$LANG['setup'][229]="Prova d'enviament de missatges de correu electrònic a l'administrador"; 
$LANG['setup'][231]="Utilitzar un servidor SMTP per a l'enviament de correu electrònic"; 
$LANG['setup'][232]="Servidor SMTP"; 
$LANG['setup'][234]="Login SMTP"; 
$LANG['setup'][235]="Contrassenya SMTP"; 
$LANG['setup'][236]="Tècnic abans encarregat de la incidència"; 
$LANG['setup'][237]="Administrador"; 
$LANG['setup'][239]="Tècnic encarregat de la incidència"; 
$LANG['setup'][240]="Opcions de notificació"; 
$LANG['setup'][241]="No hi ha criteris personals. Vols crear paràmetres personals?"; 
$LANG['setup'][242]="Opcions d'alertes"; 
$LANG['setup'][243]="Alertes sobre consumibles"; 
$LANG['setup'][244]="Alertes sobre cartutxos"; 
$LANG['setup'][245]="Recordatoris"; 
$LANG['setup'][246]="Alertes sobre contractes"; 
$LANG['setup'][247]="Alertes sobre dades financeres"; 
$LANG['setup'][248]="Grup encarregat de l'incident"; 
$LANG['setup'][249]="Grup sol·licitant"; 
$LANG['setup'][250]="Vistes predeterminades"; 
$LANG['setup'][252]="Selecciona els elements que es mostraran de forma predeterminada"; 
$LANG['setup'][253]="Filtre per a cerca als grups"; 
$LANG['setup'][254]="Tipus de cerca"; 
$LANG['setup'][255]="Atribut dels grups que contenen els usuaris"; 
$LANG['setup'][256]="Als usuaris"; 
$LANG['setup'][257]="Als grups"; 
$LANG['setup'][258]="Usuaris i grups"; 
$LANG['setup'][259]="Pertinença a grups"; 
$LANG['setup'][260]="Atribut de l'usuari que indica els seus grups"; 
$LANG['setup'][261]="DN del grup"; 
$LANG['setup'][262]="Utilitzar DN a la cerca"; 
$LANG['setup'][263]="Filtre de cerques per a usuaris"; 
$LANG['setup'][264]="Avis d'expiració de llicències"; 
$LANG['setup'][271]="Restringir la gestió de monitors"; 
$LANG['setup'][272]="Restringir la gestió de perifèrics"; 
$LANG['setup'][273]="Restringir la gestió de telèfons"; 
$LANG['setup'][274]="per afegir manualment"; 
$LANG['setup'][275]="Restringir la gestió d'impressores"; 
$LANG['setup'][280]="Actualització automàtica dels elements relacionats amb els ordinadors"; 
$LANG['setup'][281]="Connectar/actualitzar comportament"; 
$LANG['setup'][282]="Desconnectar comportament"; 
$LANG['setup'][283]="Copiar"; 
$LANG['setup'][284]="Netejar"; 
$LANG['setup'][285]="No copiar"; 
$LANG['setup'][286]="No esborrar"; 
$LANG['setup'][300]="Comprovar si hi ha una nova versió disponible"; 
$LANG['setup'][301]="Hi ha disponible una nova versió"; 
$LANG['setup'][302]="El trobarà al lloc de GLPI : <a href='http://glpi-project.org' target='_blank'>http://glpi-project.org</a>"; 
$LANG['setup'][303]="Té instal·lada l'última versió disponible"; 
$LANG['setup'][304]="Verificació impossible. Si està darrera d'un proxy, configuri'l."; 
$LANG['setup'][305]="Tots els dies"; 
$LANG['setup'][306]="Comprovar la presència d'actualitzacions"; 
$LANG['setup'][307]="Mai"; 
$LANG['setup'][308]="Totes les setmanes"; 
$LANG['setup'][309]="Tots els mesos"; 
$LANG['setup'][310]="Connexió al lloc impossible."; 
$LANG['setup'][311]="Impossible connectar-se al servidor proxy"; 
$LANG['setup'][312]="No hi ha dades disponibles en aquest lloc web"; 
$LANG['setup'][313]="Atenció: no existeix el valor per defecte"; 
$LANG['setup'][350]="Relació amb els materials per a l'obertura d'incidències"; 
$LANG['setup'][351]="Tots els materials"; 
$LANG['setup'][352]="Materials associables amb una incidència"; 
$LANG['setup'][360]="Camps automàtics (marcats amb *)"; 
$LANG['setup'][400]="Configuració del proxy"; 
$LANG['setup'][407]="Enllaç a l'Ajuda del CAU"; 
$LANG['setup'][408]="Enllaç a l'Ajuda Central"; 
$LANG['setup'][409]="Assumpte predeterminat dels documents relacionats amb el seguiment"; 
$LANG['setup'][503]="Models de telèfons"; 
$LANG['setup'][504]="Tipus de telèfons"; 
$LANG['setup'][505]="Tipus d'alimentació del telèfon"; 
$LANG['setup'][601]="Valor LDAP"; 
$LANG['setup'][602]="Connexió a la base de dades OCSNG"; 
$LANG['setup'][603]="Afegir un usuari"; 
$LANG['setup'][604]="Associar a un grup"; 
$LANG['setup'][606]="No es poden afegir. Aquest usuari ja existeix."; 
$LANG['setup'][607]="Associar un perfil"; 
$LANG['setup'][608]="Programa associable a un incident per defecte"; 
$LANG['setup'][609]="Impossible afegir. El servidor OCSNG ja existeix."; 
$LANG['setup'][610]="Títol d'incidència obligatori"; 
$LANG['setup'][611]="El contingut de l'incident es obligatori"; 
$LANG['setup'][612]="La categoria de l'incident es obligatoria"; 
$LANG['setup'][613]="Afegir un usuari LDAP sense drets"; 
$LANG['setup'][614]="Impossible actualitzar l'accés. L'usuari ja existeix,"; 
$LANG['setup'][615]="Cicle de vida dels incidents"; 
$LANG['setup'][616]="De \ A"; 
$LANG['setup'][620]="Enllaç"; 
$LANG['setup'][621]="Filtro de cerca de les entitats"; 
$LANG['setup'][622]="Atribut en representació de l'entitat"; 
$LANG['setup'][623]="Importar entitats des de LDAP"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Servidor de correu"; 
$LANG['setup'][661]="Configuració de les notificacions impossibles : activar el seguiment per correu electrònic"; 
$LANG['setup'][703]="General"; 
$LANG['setup'][704]="Notificacions"; 
$LANG['setup'][707]="Alertes sobre reserves"; 
$LANG['setup'][708]="Alertes d'incidents sense resoldre des de fa"; 
$LANG['setup'][720]="Info. Sistema"; 
$LANG['setup'][721]="Informació sobre la instal·lació i configuració del sistema"; 
$LANG['setup'][722]="Per a enganxar/copiar a la seva petició de suport"; 
$LANG['setup'][731]="Valor de la configuració general"; 
$LANG['setup'][732]="Domini del servei de correu electrònic"; 
$LANG['setup'][800]="Replicat MySQL"; 
$LANG['setup'][801]="Activar la replica MySQL"; 
$LANG['setup'][802]="Base"; 
$LANG['setup'][803]="Diferencia entre mestre i esclau"; 
$LANG['setup'][806]="Màxima diferencia entre mestre i esclau"; 
$LANG['setup'][807]="La base de dades esclava està de-sincronitzada. La diferencia es de:"; 
$LANG['setup'][808]="Base de coneixements esclava desincronitzada !"; 
$LANG['setup'][809]="Replicar MySQL: solament lectura"; 
$LANG['setup'][810]="Desincronització de la replica de MYSQL"; 

$LANG['software'][1]="Versió de compra"; 
$LANG['software'][2]="Versió d'ús"; 
$LANG['software'][3]="Llicencies afectades i no instal·lades"; 
$LANG['software'][4]="Il·limitat"; 
$LANG['software'][5]="Versions"; 
$LANG['software'][6]="Editor"; 
$LANG['software'][7]="Afegir una versió"; 
$LANG['software'][8]="Afegir una llicència"; 
$LANG['software'][11]="Llicencies"; 
$LANG['software'][17]="Programari instal·lat"; 
$LANG['software'][19]="Instal·lacions"; 
$LANG['software'][20]="Restant"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Actualització"; 
$LANG['software'][30]="Tipus de llicència"; 
$LANG['software'][32]="Expiració"; 
$LANG['software'][44]="Instal·lació d'un programa"; 
$LANG['software'][45]="Desinstal.lació d'un programari"; 
$LANG['software'][46]="Associable a un incident"; 
$LANG['software'][47]="Agrupació"; 
$LANG['software'][48]="Reagrupar"; 
$LANG['software'][49]="Programes enviats a la paperera després de reagrupar"; 
$LANG['software'][50]="Assignant a la computadora"; 
$LANG['software'][51]="El número ha de ser 1 per que surti efecte"; 

$LANG['softwarecategories'][2]="Programes sense categories"; 
$LANG['softwarecategories'][3]="Programari sense categoritzar instal·lat"; 
$LANG['softwarecategories'][4]="Desplegar programes pertanyents a una categoria"; 
$LANG['softwarecategories'][5]="Categoria de programari"; 

$LANG['state'][0]="Estat"; 
$LANG['state'][6]="Tipus de material"; 
$LANG['state'][7]="No s'han trobat materials"; 
$LANG['state'][11]="Resum"; 

$LANG['stats'][0]="Selecciona les estadístiques a visualitzar"; 
$LANG['stats'][1]="Globals"; 
$LANG['stats'][2]="No hi ha articles per a mostrar"; 
$LANG['stats'][3]="Per títols"; 
$LANG['stats'][5]="Total d'incidents oberts"; 
$LANG['stats'][6]="Demora mitjana del tractament d'incidències"; 
$LANG['stats'][7]="Veure gràfics"; 
$LANG['stats'][11]="Incidència tancades"; 
$LANG['stats'][13]="Incidència assignades"; 
$LANG['stats'][15]="Duració mitjana del tractament d'incidències"; 
$LANG['stats'][16]="Nom del tècnic"; 
$LANG['stats'][20]="Nom d'usuari"; 
$LANG['stats'][23]="No hi ha estadístiques disponibles"; 
$LANG['stats'][25]="Duració real mitjana de tractament del servei"; 
$LANG['stats'][27]="Duració real total de serveis"; 
$LANG['stats'][30]="Demora mitjana d'atenció de servei"; 
$LANG['stats'][31]="Dies"; 
$LANG['stats'][33]="Mins"; 
$LANG['stats'][34]="Segs"; 
$LANG['stats'][35]="Serveis"; 
$LANG['stats'][44]="Nom del proveïdor"; 
$LANG['stats'][45]="Per material"; 
$LANG['stats'][47]="Per incidents"; 
$LANG['stats'][48]="(assignat)"; 
$LANG['stats'][49]="(seguiments)"; 

$LANG['title'][5]="Base de coneixement"; 
$LANG['title'][6]="Material de xarxa"; 
$LANG['title'][9]="Estats dels materials"; 
$LANG['title'][10]="Seguiment d'incidències"; 
$LANG['title'][13]="Informació de l'usuari"; 
$LANG['title'][14]="Fonts d'autenticació externes"; 
$LANG['title'][24]="Suport"; 
$LANG['title'][26]="Principal"; 
$LANG['title'][27]="Connexions"; 
$LANG['title'][28]="Incidències"; 
$LANG['title'][30]="Components"; 
$LANG['title'][33]="Enllaços externs"; 
$LANG['title'][34]="Enllaç"; 
$LANG['title'][37]="Notes"; 
$LANG['title'][38]="Històric"; 
$LANG['title'][40]="Notes personals i públiques"; 
$LANG['title'][42]="Modificació massiva"; 
$LANG['title'][43]="Registre del sistema"; 

$LANG['tracking'][1]="Els meus materials"; 
$LANG['tracking'][2]="O cerca completa"; 
$LANG['tracking'][3]="Dades invàlides. Actualització cancel·lada"; 
$LANG['tracking'][4]="La seva petició no té urgència, mirar de corregir"; 
$LANG['tracking'][8]="La teva incidència no té descripció. Si us plau, completa-la."; 
$LANG['tracking'][9]="Origen per defecte per a helpdesk"; 
$LANG['tracking'][10]="Origen per defecte pels recol·lectors"; 
$LANG['tracking'][24]="Document d'Incidència"; 
$LANG['tracking'][29]="Quantitat"; 
$LANG['tracking'][30]="Noves"; 
$LANG['tracking'][31]="En curs (assignades)"; 
$LANG['tracking'][32]="En curs (planificades)"; 
$LANG['tracking'][34]="Directa"; 
$LANG['tracking'][35]="Escrita"; 
$LANG['tracking'][37]="Conservar les incidències al purgar un element de l'inventari"; 
$LANG['tracking'][38]="Correu de seguiment enviat a"; 
$LANG['tracking'][39]="Visible a l'interface del Helpdesk"; 

$LANG['transfer'][1]="Transferència"; 
$LANG['transfer'][3]="Si ja no s'utilitza"; 
$LANG['transfer'][4]="Buidar la llista d'elements a transferir"; 
$LANG['transfer'][5]="Pot afegir més elements o transferir els que hi ha ara"; 
$LANG['transfer'][6]="Es recomana fer una copia de seguretat abans de transferir elements."; 
$LANG['transfer'][7]="Elements a transferir"; 
$LANG['transfer'][8]="Mode de transferència"; 

$LANG['update'][88]="La seva versió de la base de dades no és compatible amb la versió del codi instal·lat. És necessària una actualització"; 
$LANG['update'][89]="Intentes utilitzar GLPI amb una versió de la base de dades prevista per a una versió superior. Si us plau, instal·la la versió corresponent a la seva base de dades."; 
$LANG['update'][90]="Error durant l'actualització de la base de dades"; 
$LANG['update'][91]="Atenció!"; 
$LANG['update'][92]="Actualitzaràs la base de dades GLPI que es diu:"; 
$LANG['update'][93]="La connexió amb la BD ha estat correcta"; 
$LANG['update'][94]="L'actualització ha estat correcta, la seva BD està actualitzada"; 
$LANG['update'][95]="La connexió a la BD ha fallat, comprovi els paràmetres de connexió que figuren a l'arxiu config_db.php"; 
$LANG['update'][96]="Al afegir aquest nou tipus d'usuari, tots els usuaris que tinguessin anteriorment els permisos de 'admin' rebran permisos de 'super-admin'"; 
$LANG['update'][105]="Impossible accedir a l'actualització d'aquesta forma!"; 
$LANG['update'][106]="Tornar a GLPI"; 
$LANG['update'][107]="Ara ha de procedir a l'actualització del contingut anterior de la seva base de dades"; 
$LANG['update'][130]="Actualització de llocs"; 
$LANG['update'][131]="La nova estructura és jeràrquica"; 
$LANG['update'][132]="Si utilitza un caràcter de separació, pot indicar-lo per automatitzar la generació de la jerarquia"; 
$LANG['update'][133]="Pot també especificar un lloc de base que inclou tots els llocs generats"; 
$LANG['update'][134]="Caràcter de separació"; 
$LANG['update'][135]="Lloc arrel"; 
$LANG['update'][136]="Aquí tens la nova jerarquia. Si es correcta pots validar-la"; 
$LANG['update'][137]="Nova jerarquia"; 
$LANG['update'][138]="Llocs actuals"; 
$LANG['update'][139]="Optimizació de les taules"; 
$LANG['update'][140]="Crear índexs"; 
$LANG['update'][141]="Modificació de l'esquema"; 
$LANG['update'][142]="Recuperació de Dades"; 

$LANG['users'][1]="Títol"; 
$LANG['users'][2]="Categoria"; 

$LANG['validation'][0]="Validació"; 
$LANG['validation'][1]="Enviar una sol·licitud de validació"; 
$LANG['validation'][2]="Estat"; 
$LANG['validation'][3]="Data de la sol·licitud"; 
$LANG['validation'][4]="Data de la validació"; 
$LANG['validation'][5]="Comentari de la sol·licitud"; 
$LANG['validation'][6]="Comentari de la validació"; 
$LANG['validation'][7]="Validació(ns) per l'incident"; 
$LANG['validation'][9]="En espera de validació"; 
$LANG['validation'][10]="Rebutjat"; 
$LANG['validation'][11]="Acceptada"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Sol·licitud de validació enviada a"; 
$LANG['validation'][15]="Incident en espera de la seva validació"; 
$LANG['validation'][16]="Opcional si acceptada"; 
$LANG['validation'][18]="Sol·licitant de la validació"; 
$LANG['validation'][19]="Validació acceptada"; 
$LANG['validation'][20]="Validació rebutjada"; 
$LANG['validation'][21]="Usuari de validació"; 
$LANG['validation'][23]="L'usuari escollit no te correu electrònic. La petició s'ha creat però l'enviament del correu ha fallat."; 
$LANG['validation'][26]="Sol·licitud de validació"; 
$LANG['validation'][27]="S'ha sol·licitat una petició de validació"; 
$LANG['validation'][28]="Estat de la petició de validació"; 
$LANG['validation'][29]="En cas de rebutjar la petició, s'ha d'indicar un motiu"; 
$LANG['validation'][30]="Suprimir la sol·licitud de validació"; 
$LANG['validation'][31]="Actualitzar la sol·licitud de validació"; 
$LANG['validation'][32]="Una resposta a una sol·licitud de validació s'ha portat a terme"; 
$LANG['validation'][33]="Incidents esperen la seva aprovació"; 
?>